@@ -40,28 +40,13 @@ AdvancedSettingsDialog::AdvancedSettingsDialog(QWidget *parent, const QString& c
 	this->currentProfile = currentProfile;
 	this->connectionType = connectionType;
 
-
-	connect (main->AdvancedSettingsCheckbox, SIGNAL(toggled(bool)),
-	         this, SLOT(advancedSettingsToggled(bool)));
-
-	connect (main->NtDomainNameCheckbox, SIGNAL(toggled(bool)),
-	         this, SLOT(domainNameToggled(bool)));
-
-	connect (main->ApplicationVersionCheckbox, SIGNAL(toggled(bool)),
-	         this, SLOT(applicationVersionToggled(bool)));
-
-	connect (main->PerfectForwardSecurityCheckbox, SIGNAL(toggled(bool)),
-	         this, SLOT(perfectForwardSecurityToggled(bool)));
-
-	connect (main->IkeGroupCheckbox, SIGNAL(toggled(bool)),
-	         this, SLOT(IkeGroupToggled(bool)));
-
-	connect (main->SingleDesCheckbox, SIGNAL(toggled(bool)),
-	         this, SLOT(singleDesToggled(bool)));
-
-	connect (main->LocalPortCheckbox, SIGNAL(toggled(bool)),
-	         this, SLOT(localPortToggled(bool)));
-
+	connect (main->AdvancedSettingsCheckbox, SIGNAL(toggled(bool)),this, SLOT(advancedSettingsToggled(bool)));
+	connect (main->NtDomainNameCheckbox, SIGNAL(toggled(bool)),this, SLOT(domainNameToggled(bool)));
+	connect (main->ApplicationVersionCheckbox, SIGNAL(toggled(bool)),this, SLOT(applicationVersionToggled(bool)));
+	connect (main->PerfectForwardSecurityCheckbox, SIGNAL(toggled(bool)),this, SLOT(perfectForwardSecurityToggled(bool)));
+	connect (main->IkeGroupCheckbox, SIGNAL(toggled(bool)),this, SLOT(IkeGroupToggled(bool)));
+	connect (main->SingleDesCheckbox, SIGNAL(toggled(bool)),this, SLOT(singleDesToggled(bool)));
+	connect (main->LocalPortCheckbox, SIGNAL(toggled(bool)),this, SLOT(localPortToggled(bool)));
 
 	main->LocalPortCheckbox->setEnabled( false );
 	main->IkeGroupCheckbox->setEnabled( false );
@@ -91,7 +76,7 @@ AdvancedSettingsDialog::AdvancedSettingsDialog(QWidget *parent, const QString& c
 		}
 	}
 
-	
+
 
 	if (currentProfile->getConnectionType() == VpnAccountData::ConnectionType(VpnAccountData::cisco))
 	{
@@ -144,9 +129,10 @@ AdvancedSettingsDialog::AdvancedSettingsDialog(QWidget *parent, const QString& c
 	this->advancedSettingsToggled(true);
 }
 
-
 AdvancedSettingsDialog::~AdvancedSettingsDialog()
-{}
+{
+	delete main;
+}
 
 void AdvancedSettingsDialog::advancedSettingsToggled(bool)
 {
@@ -256,7 +242,6 @@ void AdvancedSettingsDialog::localPortToggled(bool)
 		main->LocalPortSpinbox->setEnabled( false );
 }
 
-
 void AdvancedSettingsDialog::accept()
 {
 	currentProfile->setUseAdvancedSettings( this->main->AdvancedSettingsCheckbox->isChecked() );
