@@ -31,10 +31,16 @@ DebugOutputTextEdit::DebugOutputTextEdit( QWidget* parent, const char* name)
 
 }
 
+DebugOutputTextEdit::~DebugOutputTextEdit()
+{
+	delete popup;
+}
+
 QPopupMenu* DebugOutputTextEdit::createPopupMenu(const QPoint &)
 {
 	popup = new QPopupMenu(this);
 	popup->insertItem(i18n("Cut Content"), this, SLOT(cut() ) );
+ 	popup->insertItem(i18n("Copy Content"), this, SLOT(copy() ) );
 	popup->insertSeparator();
 	popup->insertItem(i18n("Clear Log Window"), this, SLOT(clear() ) );
   popup->insertSeparator();
@@ -46,5 +52,3 @@ void DebugOutputTextEdit::append ( const QString & text )
 {
 	QTextEdit::append(text);
 }
-
-
