@@ -49,7 +49,9 @@ EnterUsernamePasswordDialog::EnterUsernamePasswordDialog(QWidget *parent, const
 }
 
 EnterUsernamePasswordDialog::~ EnterUsernamePasswordDialog()
-{}
+{
+	delete main;
+}
 
 
 void EnterUsernamePasswordDialog::accept()
