@@ -46,7 +46,9 @@ GenerateOpenvpnKeyDialog::GenerateOpenvpnKeyDialog(KVpncConfig *GlobalConfig,QWi
 }
 
 GenerateOpenvpnKeyDialog::~GenerateOpenvpnKeyDialog()
-{}
+{
+	delete main;
+}
 
 void GenerateOpenvpnKeyDialog::accept()
 {
@@ -54,10 +56,14 @@ void GenerateOpenvpnKeyDialog::accept()
 	//filename="/etc/CiscoSystemsVPNClient/Profiles/hs_harz.pcf";
 	filename = main->FilenameUrlrequester->url();
 	if ( !filename.isEmpty() )
+	{
 		canAccept();
+		delete generateOpenvpnKeyProcess;
+	}
 
 	else
 	{
+		GlobalConfig->appendLogEntry( i18n("GenerateOpenvpnKeyDialog: empty file name"), GlobalConfig->error);
 		KMessageBox::sorry( 0, i18n( "File name can not be empty!" ), i18n( "Empty File Name" ) );
 	}
 }
@@ -85,11 +91,12 @@ void GenerateOpenvpnKeyDialog::canAccept()
 	connect( generateOpenvpnKeyProcess, SIGNAL( readyReadStdout() ), this, SLOT( readStdErr() ) );
 	if ( !generateOpenvpnKeyProcess->start() )
 	{
-		KMessageBox::sorry( this, i18n( "\"%1\" start failed!" ).arg( "openvpn" ) );
+		KMessageBox::sorry( this, i18n( "Generating of %1 key failed!" ).arg( "openvpn" ) );
 		GlobalConfig->appendLogEntry(i18n( "\"%1\" start failed!" ).arg( "openvpn" ),GlobalConfig->error);
 	}
 	else
 	{
+		GlobalConfig->appendLogEntry( i18n("Generating of %1 key was successful.").arg("openvpn"), GlobalConfig->info);
 		genOk = true;
 	}
 
