@@ -2,6 +2,10 @@
 *   Copyright (C) 2004 by Christoph Thielecke                             *
 *   crissi99@gmx.de                                                       *
 *                                                                         *
+*   @description This class imports a certificate                             *
+*                                                                         *
+*   @author Christoph Thielecke <crissi99@gmx.de>                    *
+*                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
@@ -30,9 +34,11 @@
 #include <qfile.h>
 #include <qdir.h>
 #include <qtextstream.h>
+#include <qcursor.h>
 #include <qurl.h>
 #include <iostream>
 #include "kvpncconfig.h"
+#include "utils.h"
 //END includes
 
 ImportCertificateDialog::ImportCertificateDialog( QWidget *parent, const char* caption, KVpncConfig *GlobalConfig)
@@ -46,9 +52,12 @@ ImportCertificateDialog::ImportCertificateDialog( QWidget *parent, const char* c
 	this->GlobalConfig = GlobalConfig;
 	filename = "";
 	certHash = "";
+	CertFullPath="";
+	CaCertFullPath="";
 	importOk = false;
 	importSuccess = true;
 	doHash = false;
+	doExit=true;
 	certName = "";
 	certpath = "/etc/racoon/certs/";
 	pathToOpenSSL = GlobalConfig->pathToOpenssl;
@@ -56,7 +65,7 @@ ImportCertificateDialog::ImportCertificateDialog( QWidget *parent, const char* c
 	main->FilenameUrlrequester->setFilter( "*.p12" );
 
 	connect (main->ImporttypeComboBox, SIGNAL(activated(int)), this, SLOT(typeToggeled(int)));
-	typeToggeled( 0 );
+	typeToggeled( main->ImporttypeComboBox->currentItem() );
 
 
 	// TMP
@@ -73,7 +82,9 @@ ImportCertificateDialog::ImportCertificateDialog( QWidget *parent, const char* c
 }
 
 ImportCertificateDialog::~ImportCertificateDialog()
-{}
+{
+	delete main;
+}
 
 void ImportCertificateDialog::accept()
 {
@@ -99,6 +110,8 @@ void ImportCertificateDialog::accept()
 	// 		return;
 	// 	}
 
+	GlobalConfig->appPointer->setOverrideCursor( QCursor(Qt::WaitCursor) );
+
 	QFile f( filename );
 	if ( f.exists() )
 	{
@@ -112,6 +125,7 @@ void ImportCertificateDialog::accept()
 			GlobalConfig->appendLogEntry ( i18n( "Certificate import: file \"%1\" does not exist." ).arg( filename ),GlobalConfig->error );
 
 			importOk = false;
+			GlobalConfig->appPointer->restoreOverrideCursor();
 			return;
 		}
 	}
@@ -121,14 +135,16 @@ void ImportCertificateDialog::accept()
 
 		GlobalConfig->appendLogEntry ( i18n( "Certificate import: file \"%1\" is not readable." ).arg( filename ),GlobalConfig->error );
 		importOk = false;
+		GlobalConfig->appPointer->restoreOverrideCursor();
 		return;
 	}
 
 	if ( main->ImporttypeComboBox->currentItem() == pkcs12_freeswan )
 	{
-		if ( !QDir("/etc/ipsec.d").exists())
+		certpath="/etc/ipsec.d";
+		if ( !QDir(certpath).exists())
 		{
-			if (!QDir().mkdir("/etc/ipsec.d"))
+			if (!QDir().mkdir(certpath))
 			{
 				KMessageBox::error( this, i18n( "\"%1\" could not be created!" ).arg( "/etc/ipsec.d" ) );
 				GlobalConfig->appendLogEntry ( i18n( "Certificate import: directory \"%1\" does not exist and could not be created." ).arg( "/etc/ipsec.d" ),GlobalConfig->error );
@@ -165,6 +181,22 @@ void ImportCertificateDialog::accept()
 	}
 	else if ( main->ImporttypeComboBox->currentItem() == pkcs12_racoon || main->ImporttypeComboBox->currentItem() == ca_der )
 	{
+		certpath="/etc/racoon/certs";
+		if ( !QDir(certpath).exists())
+			if (!QDir().mkdir(certpath))
+			{
+				KMessageBox::error( this, i18n( "\"%1\" could not be created!" ).arg( certpath ) );
+				GlobalConfig->appendLogEntry ( i18n( "Certificate import: directory \"%1\" does not exist." ).arg( certpath ),GlobalConfig->error );
+			}
+			else
+			{
+				if (GlobalConfig->KvpncDebugLevel > 0 )
+					GlobalConfig->appendLogEntry ( i18n( "Certificate import: directory \"%1\" does not exist but was successful created." ).arg( certpath ),GlobalConfig->debug );
+			}
+	}
+	else if ( main->ImporttypeComboBox->currentItem() == pkcs12_openvpn )
+	{
+		certpath="/etc/openvpn";
 		if ( !QDir(certpath).exists())
 			if (!QDir().mkdir(certpath))
 			{
@@ -178,15 +210,16 @@ void ImportCertificateDialog::accept()
 			}
 	}
 
-
-	if ( (main->ImporttypeComboBox->currentItem() == pkcs12_freeswan ||
-	        main->ImporttypeComboBox->currentItem() == pkcs12_racoon ) &&
-	        importpassword.isEmpty() )
-	{
-		importOk = false;
-		KMessageBox::sorry( 0, i18n( "Password can't be empty!" ), i18n( "Empty Password" ) );
-		return;
-	}
+// 	if ( (main->ImporttypeComboBox->currentItem() == pkcs12_freeswan ||
+// 	        main->ImporttypeComboBox->currentItem() == pkcs12_racoon ||
+// 					main->ImporttypeComboBox->currentItem() == pkcs12_racoon
+// 			) &&
+// 	        importpassword.isEmpty() )
+// 	{
+// 		importOk = false;
+// 		KMessageBox::sorry( 0, i18n( "Password can't be empty!" ), i18n( "Empty Password" ) );
+// 		return;
+// 	}
 
 	if ( main->ImporttypeComboBox->currentItem() == pkcs12_freeswan )
 	{
@@ -211,6 +244,10 @@ void ImportCertificateDialog::accept()
 				KMessageBox::sorry( 0, i18n( "Private key passwords does not match!" ), i18n( "Passwords Do Not Match" ) );
 				return;
 			}
+			else
+			{
+				privatekeypassword= main->PrivateKeyAgainPasswordEdit->text();
+			}
 		}
 	}
 
@@ -220,23 +257,14 @@ void ImportCertificateDialog::accept()
 	// looking for openssl
 	bool found=true;
 	QString bin="openssl";
-	ToolInfo *tool;
+	ToolInfo *tool = Utils(GlobalConfig).getToolInfo(GlobalConfig,"openssl");
 	//std::cout << "Tool (bin): " << bin << std::endl;
-	if (!GlobalConfig->ToolList->isEmpty())
+
+	if (tool->PathToExec.section('/',-1) != bin )
 	{
-		for ( tool = GlobalConfig->ToolList->first(); tool; tool = GlobalConfig->ToolList->next() )
-		{
-			if (bin == tool->Name)
-			{
-				if (tool->PathToExec.section('/',-1) != bin )
-				{
-					// program is NOT installed
-					KMessageBox::error ( this, i18n( "The required tool (%1) is not installed, please install it first and restart kvpnc.").arg(bin), i18n( "Tool Missing" ) );
-					found=false;
-				}
-				break;
-			}
-		}
+		// program is NOT installed
+		KMessageBox::error ( this, i18n( "The required tool (%1) is not installed, please install it first and restart kvpnc.").arg(bin), i18n( "Tool Missing" ) );
+		found=false;
 	}
 
 	if( !found)
@@ -250,15 +278,20 @@ void ImportCertificateDialog::accept()
 	QString file = QUrl ( filename ).fileName();
 	certName = file.left( file.length() - 4 ); // peter_pan.p12 -> peter_pan
 
-	if ( main->ImporttypeComboBox->currentItem()
-	        == pkcs12_racoon )
+	if ( main->ImporttypeComboBox->currentItem() == pkcs12_racoon || main->ImporttypeComboBox->currentItem() == pkcs12_openvpn )
 	{
+		QString type="";
+		if ( main->ImporttypeComboBox->currentItem() == pkcs12_racoon)
+			type="racoon";
+		else
+			type="OpenVPN";
+
 		QFile certpathtest( certpath + "/." );
 
 		if ( !certpathtest.exists() )
 		{
-			KMessageBox::error( this, i18n( "racoon certificate path (%1) does not exist!" ).arg( certpath ) );
-			GlobalConfig->appendLogEntry(i18n( "racoon certificate path (%1) does not exist!" ).arg( certpath ) ,GlobalConfig->error);
+			KMessageBox::error( this, i18n( "%1 certificate path (%2) does not exist!" ).arg(type).arg( certpath ) );
+			GlobalConfig->appendLogEntry(i18n( "%1 certificate path (%2) does not exist!" ).arg(type).arg( certpath ) ,GlobalConfig->error);
 			importOk=false;
 		}
 		else
@@ -266,8 +299,8 @@ void ImportCertificateDialog::accept()
 			QFile testfile ( QString(certpath + "/test" ));
 			if ( !testfile.open( IO_WriteOnly ) )
 			{
-				KMessageBox::error( this, i18n( "racoon certificate path (%1) is not writeable!" ).arg( certpath ) );
-				GlobalConfig->appendLogEntry(i18n( "racoon certificate path (%1) is not writeable!" ).arg( certpath )  ,GlobalConfig->error);
+				KMessageBox::error( this, i18n( "%1 certificate path (%2) is not writeable!" ).arg(type).arg( certpath ) );
+				GlobalConfig->appendLogEntry(i18n( "%1 certificate path (%2) is not writeable!" ).arg(type).arg( certpath )  ,GlobalConfig->error);
 				importOk = false;
 			}
 			else
@@ -296,7 +329,8 @@ void ImportCertificateDialog::accept()
 		ImportProcess->addArgument( pathToOpenSSL );
 
 		if ( main->ImporttypeComboBox->currentItem() == pkcs12_freeswan ||
-		        main->ImporttypeComboBox->currentItem() == pkcs12_racoon
+		        main->ImporttypeComboBox->currentItem() == pkcs12_racoon ||
+						main->ImporttypeComboBox->currentItem() == pkcs12_openvpn
 		   )
 		{
 			ImportProcess->addArgument( "pkcs12" );
@@ -320,7 +354,7 @@ void ImportCertificateDialog::accept()
 		{
 			ImportProcess->addArgument( "/etc/ipsec.d/certs/mykeys_" + certName + ".pem" ); // warning: static
 		}
-		else if( main->ImporttypeComboBox->currentItem() == pkcs12_racoon )
+		else if( main->ImporttypeComboBox->currentItem() == pkcs12_racoon || main->ImporttypeComboBox->currentItem() == pkcs12_openvpn )
 		{
 			ImportProcess->addArgument( certpath + "/mykeys_" + certName + ".pem" );
 		}
@@ -329,7 +363,8 @@ void ImportCertificateDialog::accept()
 		connect( ImportProcess, SIGNAL( readyReadStdout() ), this, SLOT( readFromStdout_import() ) );
 		connect( ImportProcess, SIGNAL( readyReadStderr() ), this, SLOT( readFromStderr_import() ) );
 		if ( main->ImporttypeComboBox->currentItem() == pkcs12_freeswan ||
-		        main->ImporttypeComboBox->currentItem() == pkcs12_racoon
+		        main->ImporttypeComboBox->currentItem() == pkcs12_racoon ||
+						main->ImporttypeComboBox->currentItem() == pkcs12_openvpn
 		   )
 		{
 			connect( ImportProcess, SIGNAL( processExited () ), this, SLOT( doCacert() ) );
@@ -345,11 +380,13 @@ void ImportCertificateDialog::accept()
 		}
 		else
 		{
+			doExit=true;
 			if (GlobalConfig->KvpncDebugLevel > 0 )
 				GlobalConfig->appendLogEntry ( i18n( "Process (%1) started." ).arg( "openssl" ),GlobalConfig->debug );
 		}
 	}
 }
+
 void ImportCertificateDialog::canAccept()
 {
 	if (importSuccess)
@@ -406,8 +443,31 @@ void ImportCertificateDialog::canAccept()
 			}
 		}
 	}
+	else if ( main->ImporttypeComboBox->currentItem() == pkcs12_openvpn)
+	{
+		QString bin="openvpn";
+		ToolInfo *tool;
+		//std::cout << "Tool (bin): " << bin << std::endl;
+		if (!GlobalConfig->ToolList->isEmpty())
+		{
+			for ( tool = GlobalConfig->ToolList->first(); tool; tool = GlobalConfig->ToolList->next() )
+			{
+				if (bin == tool->Name)
+				{
+					if (tool->PathToExec.section('/',-1) != bin )
+					{
+						// program is NOT installed
+						KMessageBox::information ( this, i18n( "The required tool (%1) is not installed, please install it before you are connecting and restart kvpnc.").arg(bin), i18n( "Tool Missing" ) );
+					}
+					break;
+				}
+			}
+		}
+	}
+	GlobalConfig->appPointer->restoreOverrideCursor();
 
-	QDialog::accept();
+		if (doExit)
+			QDialog::accept();
 }
 
 void ImportCertificateDialog::doCacert()
@@ -417,6 +477,16 @@ void ImportCertificateDialog::doCacert()
 		if (GlobalConfig->KvpncDebugLevel > 0 )
 			GlobalConfig->appendLogEntry ( i18n( "Certificate import: doCacert()" ),GlobalConfig->debug );
 		disconnect( ImportProcess, SIGNAL( processExited () ), this, SLOT( doCacert() ) );
+
+		if ( main->ImporttypeComboBox->currentItem() == pkcs12_freeswan )
+		{
+			Utils(GlobalConfig,this).doChmod("/etc/ipsec.d/certs/mykeys_" + certName + ".pem","go-rwx");
+		}
+		else if( main->ImporttypeComboBox->currentItem() == pkcs12_racoon || main->ImporttypeComboBox->currentItem() == pkcs12_openvpn )
+		{
+			Utils(GlobalConfig,this).doChmod(certpath + "/mykeys_" + certName + ".pem","go-rwx");
+		}
+
 		/*
 		openssl pkcs12 -in cert.p12 -nokeys -cacerts -out /etc/racoon/certs/ca_company.pem -nodes
 		*/
@@ -430,9 +500,15 @@ void ImportCertificateDialog::doCacert()
 		ImportProcess->addArgument( "-out" );
 
 		if ( main->ImporttypeComboBox->currentItem() == pkcs12_freeswan )
+		{
 			ImportProcess->addArgument( "/etc/ipsec.d/cacerts/ca_" + certName + ".pem" ); // warning: static
+			CaCertFullPath="/etc/ipsec.d/cacerts/ca_" + certName + ".pem";
+		}
 		else
+		{
 			ImportProcess->addArgument( certpath + "/ca_" + certName + ".pem" );
+			CaCertFullPath=certpath + "/ca_" + certName + ".pem";
+		}
 
 		ImportProcess->addArgument( "-nodes" );
 
@@ -446,6 +522,7 @@ void ImportCertificateDialog::doCacert()
 		}
 		else
 		{
+			doExit=true;
 			if (GlobalConfig->KvpncDebugLevel > 0 )
 				GlobalConfig->appendLogEntry ( i18n( "Certificate import: CA certificate successful extracted." ),GlobalConfig->debug );
 		}
@@ -456,7 +533,7 @@ void ImportCertificateDialog::doPrivateKey()
 {
 	if ( ImportProcess->normalExit () )
 	{
-		//	LogOutput->append("[dbg]: doPrivateKey()");
+		//GlobalConfig->appendLogEntry("[dbg]: doPrivateKey()",GlobalConfig->debug);
 		disconnect( ImportProcess, SIGNAL( processExited () ), this, SLOT( doPrivateKey() ) );
 		/*
 		openssl pkcs12 -in cert.p12 -nocerts -out /etc/racoon/certs/ca_company.pem
@@ -468,7 +545,11 @@ void ImportCertificateDialog::doPrivateKey()
 		ImportProcess->addArgument( "-in" );
 		ImportProcess->addArgument( filename );
 		ImportProcess->addArgument( "-out" );
+
+
 		ImportProcess->addArgument( certpath+"/private/" + certName + ".pem" ); // warning: static
+		if (!certpath.isEmpty())
+			CertFullPath=certpath+"/private/" + certName + ".pem";
 
 		connect( ImportProcess, SIGNAL( processExited () ), this, SLOT( exit() ) );
 
@@ -476,10 +557,17 @@ void ImportCertificateDialog::doPrivateKey()
 		if ( !ImportProcess->start( ) )
 		{
 			KMessageBox::sorry( this, i18n( "Unable to start process (private key)!" ) );
+
+			GlobalConfig->appendLogEntry ( i18n( "Certificate import: private key could not extracted." ),GlobalConfig->error );
 			importSuccess=false;
 		}
 		else
-		{}
+		{
+			doExit=true;
+			privatekeypassword = main->PrivateKeyPasswordEdit->text();
+			if (GlobalConfig->KvpncDebugLevel > 0 )
+				GlobalConfig->appendLogEntry ( i18n( "Certificate import: private key successful extracted." ),GlobalConfig->debug );
+		}
 
 	}
 }
@@ -491,6 +579,11 @@ void ImportCertificateDialog::doCreateHash()
 
 		disconnect( ImportProcess, SIGNAL( processExited () ), this, SLOT( doCreateHash() ) );
 
+		if ( main->ImporttypeComboBox->currentItem() == pkcs12_freeswan )
+			Utils(GlobalConfig,this).doChmod(certpath+"/cacerts/ca_" + certName + ".pem","go-rwx");
+		else
+			Utils(GlobalConfig,this).doChmod(certpath + "/ca_" + certName + ".pem","go-rwx");
+
 		/*
 		openssl x509 -noout -hash < /etc/racoon/certs/ca_company.pem
 		*/
@@ -512,11 +605,15 @@ void ImportCertificateDialog::doCreateHash()
 		if ( !ImportProcess->start( ) )
 		{
 			KMessageBox::sorry( this, i18n( "Unable to start process (%1)!" ).arg("hash") );
+			GlobalConfig->appendLogEntry ( i18n( "Certificate import: hash could not created." ),GlobalConfig->error );
 			importSuccess=false;
 		}
 		else
 		{
+			doExit=true;
 			doHash = true;
+			if (GlobalConfig->KvpncDebugLevel > 0 )
+				GlobalConfig->appendLogEntry ( i18n( "Certificate import: hash successful created." ),GlobalConfig->debug );
 		}
 	}
 }
@@ -553,10 +650,15 @@ void ImportCertificateDialog::doLink()
 		if ( !ImportProcess->start( ) )
 		{
 			KMessageBox::sorry( this, i18n( "Unable to start process (%1)!" ).arg("ln -s") );
+				GlobalConfig->appendLogEntry ( i18n( "Certificate import: Link could not created." ),GlobalConfig->error );
 			importSuccess=false;
 		}
 		else
-		{}
+		{
+			doExit=true;
+			if (GlobalConfig->KvpncDebugLevel > 0 )
+				GlobalConfig->appendLogEntry ( i18n( "Certificate import: Link successful created." ),GlobalConfig->debug );
+		}
 	}
 }
 
@@ -564,6 +666,8 @@ void ImportCertificateDialog::exit()
 {
 	// 	if ( ImportProcess->normalExit() )
 	// 		importOk=true;
+	if ( main->ImporttypeComboBox->currentItem() == pkcs12_freeswan )
+		Utils(GlobalConfig,this).doChmod(certpath+"/private/" + certName + ".pem","go-rwx");
 	done=true;
 	canAccept();
 }
@@ -607,6 +711,7 @@ void ImportCertificateDialog::readFromStderr_import()
 	{
 		GlobalConfig->appendLogEntry ( i18n( "Certificate import: %2" ).arg(line),GlobalConfig->error );
 		importSuccess=false;
+		doExit=false;
 	}
 
 	if ( line.find( "invalid password" , 0, FALSE ) > -1 )
@@ -614,6 +719,8 @@ void ImportCertificateDialog::readFromStderr_import()
 		KMessageBox::sorry( 0, i18n( "Wrong password." ), i18n( "Password Failed" ) );
 		GlobalConfig->appendLogEntry ( i18n( "Certificate import: password was invalid" ),GlobalConfig->error );
 		importSuccess=false;
+		doExit=false;
+		GlobalConfig->appPointer->restoreOverrideCursor();
 	}
 
 	if ( line.find( "Enter Import Pass", 0, FALSE ) > -1 )
@@ -642,6 +749,8 @@ void ImportCertificateDialog::readFromStderr_import()
 		GlobalConfig->appendLogEntry( i18n( "Unable to load certificate!" ) ,GlobalConfig->error);
 		importOk=true;
 		importSuccess=false;
+		doExit=false;
+		GlobalConfig->appPointer->restoreOverrideCursor();
 		if (ImportProcess->isRunning())
 		{
 			ImportProcess->kill();
@@ -655,7 +764,7 @@ void ImportCertificateDialog::readFromStderr_import()
 
 void ImportCertificateDialog::typeToggeled( int type )
 {
-	//std::cout << "type: " << type << std::endl;
+	//GlobalConfig->appendLogEntry( QString("type: "+QString().setNum(type)),GlobalConfig->info);
 	if ( type == pkcs12_freeswan )
 	{
 		certpath = "/etc/ipsec.d/certs";
@@ -689,6 +798,17 @@ void ImportCertificateDialog::typeToggeled( int type )
 		main->FreeswanGroupBox->setEnabled( false );
 		main->FilenameUrlrequester->setFilter( "*.der *.crt" );
 	}
+	else if ( type == pkcs12_openvpn )
+	{
+		certpath = "/etc/openvpn";
+		main->PrivateKeyPasswordEdit->setEnabled( true );
+		main->PrivateKeyAgainPasswordEdit->setEnabled( true );
+		main->RacoonCertificatePathUrlrequester->setEnabled( false );
+		main->ImportPasswordEdit->setEnabled( true );
+		main->P12GroupBox->setEnabled( true );
+		main->FreeswanGroupBox->setEnabled( false );
+		main->FilenameUrlrequester->setFilter( "*.p12" );
+	}
 	main->RacoonCertificatePathUrlrequester->setURL(certpath);
 }
 
