@@ -44,13 +44,17 @@ class ImportCertificateDialog : public KDialogBase {
 		QString pathToOpenSSL;
 		QString certHash;
 		QString certName;
+		QString CertFullPath;
+		QString CaCertFullPath;
 		bool importOk;
 		bool doHash;
 		bool importSuccess;
-		QProcess *ImportProcess;
-		
+		bool doExit;
+
+		enum ImportType {pkcs12_freeswan=0,pkcs12_racoon=1,ca_der=2,pkcs12_openvpn=3};
+
 protected:
-		enum ImportType {pkcs12_freeswan=0,pkcs12_racoon=1,ca_der=2};
+		QProcess *ImportProcess;
 		KVpncConfig *GlobalConfig;
 		bool done;
 
@@ -58,7 +62,8 @@ protected:
 	public slots:
 		void accept();
 		void exit();
-	
+		void typeToggeled(int type);
+
 	private slots:
 		void readFromStdout_import();
 		void readFromStderr_import();
@@ -66,7 +71,7 @@ protected:
 		void doCacert();
 		void doPrivateKey();
 		void doCreateHash();
-		void typeToggeled(int type);
+
 
 	public:
 		ImportCertificateDialogBase *main;
