@@ -58,7 +58,9 @@ ImportProfileDialog::ImportProfileDialog(KVpncConfig *config, QWidget *parent, c
 
 
 ImportProfileDialog::~ImportProfileDialog()
-{}
+{
+	delete main;
+}
 
 void ImportProfileDialog::accept()
 {
@@ -96,7 +98,7 @@ void ImportProfileDialog::canAccept()
 	[main]
 	Description=
 	Host=192.168.13.1
-	AuthType=1 // nur auslesen 
+	AuthType=1 // nur auslesen
 	GroupName = hs_harz
 	GroupPwd =
 	Username = u15119
@@ -170,8 +172,8 @@ void ImportProfileDialog::canAccept()
 	if ( enableMSLogon && !NtDomain.isEmpty() )
 		useNtDomainName = true;
 
-	if ( TunnelingPort != -1 )
-		useLocalPort = true;
+// 	if ( TunnelingPort != -1 )
+// 		useLocalPort = true;
 
 	bool useIkeGroup = false;
 	QString IkeGroup;
@@ -179,12 +181,17 @@ void ImportProfileDialog::canAccept()
  		IkeGroup =  "dh" + QString().setNum( DHGroup ) ;
 		useIkeGroup = true;
 	}
-	
+
+	int PeerTimeout=600000; // value
+
+	if ( config.readNumEntry ("PeerTimeout",0) > 2)
+		PeerTimeout= (config.readNumEntry ("PeerTimeout",0)-1)*60; // read minutes but store seconds
+
 	QString PerfectForwardSecrecy = ""; //QString("dh"+QString().setNum(DHGroup));
 	//	bool usePerfectForwardSecrety = false;
 
 		//GroupPwd = downloadDecPasswd( enc_GroupPwd );
-		CiscoPasswdDecoder dec (filename.ascii());
+		CiscoPasswdDecoder dec (filename);
 		QString userpasswd="";
 		QString grouppasswd="";
 		dec.decodePasswords(userpasswd,grouppasswd);
@@ -235,7 +242,7 @@ void ImportProfileDialog::canAccept()
 	acc->setUseAdvancedSettings( true );
 	acc->setUsePerfectForwardSecrety( usePerfectSecrecy );
 	acc->setUseUdp( useUdp );
-	acc->setUdpPort( 10000 );
+// 	acc->setUdpPort( 10000 );
 
 	if (useLocalPort){
 		acc->setLocalPort(TunnelingPort);
