@@ -27,13 +27,16 @@
 #include <iostream>
 //END INCLUDES
 
-KVpncConfig::KVpncConfig()
+KVpncConfig::KVpncConfig(QWidget *parent)
 {
+	this->parent = parent;
+
 	pathToVpnc = "";
 	pathToRacoon = "";
 	pathToSetkey = "";
 	pathToFreeswan = "";
 	pathToPppd="";
+	pathToPptp="";
 	pathToKill="";
 	pathToKillall="";
 	pathToPing="";
@@ -74,6 +77,10 @@ KVpncConfig::KVpncConfig()
 	showStatusBar=true;
 	showToolBar=true;
 	firstUseOfKwallet=true;
+	shutdownIsCalled=false;
+	skipKwalletStoring = false;
+	hideOnCloseInfo = false;
+	enableFreeswanVerbose=false;
 
 	VpncDebugLevel = 0;
 	RacoonDebugLevel = "info";
@@ -103,9 +110,11 @@ KVpncConfig::KVpncConfig()
 	currentProfile=0L;
 }
 
-
 KVpncConfig::~KVpncConfig()
-{}
+{
+	delete AccountList;
+	delete ToolList;
+}
 
 void KVpncConfig::setLogOutput(QTextEdit *LogOutput)
 {
@@ -133,6 +142,7 @@ void KVpncConfig::appendLogEntry( QString msg, LogType type )
 				logFileStream << i18n( "Log session started at: " );
 				logFileStream << QDateTime::currentDateTime().toString( Qt::TextDate );
 				logFileStream << "\n";
+				logfile.flush();
 			}
 		}
 
@@ -159,11 +169,14 @@ void KVpncConfig::appendLogEntry( QString msg, LogType type )
 					prefix=i18n("debug")+": ";
 					break;
 			}
+			appPointer->processEvents();
 			logFileStream << date << time << prefix << msg << "\n";
+			logfile.flush();
+			appPointer->processEvents();
 		}
 
 
-		// write into debug console 
+		// write into debug console
 		QString prefix="";
 		QString postfix="";
 
@@ -224,6 +237,7 @@ void KVpncConfig::appendLogEntry( QString msg, LogType type )
 			postfix+="</font>";
 
 		LogOutput->append( prefix+msg+postfix );
+		appPointer->processEvents();
 	}
 }
 
@@ -238,6 +252,8 @@ void KVpncConfig::saveOptions()
 	config->writeEntry( "Minimize after connect", minimizeAfterConnect );
 	config->writeEntry( "Use silent quit", useSilentQuit );
 	config->writeEntry( "Dont quit on CloseEvent", dontQuitOnCloseEvent );
+	config->writeEntry( "Enable pppd debug", enableDebugPppd );
+	config->writeEntry( "Enable FreeSWAN verbose", enableFreeswanVerbose );
 	config->writeEntry( "Show debugconsole", showDebugConsole );
 	config->writeEntry( "Pid file for vpnc ", Vpnc_pid_file );
 	config->writeEntry( "Vpnc debuglevel", VpncDebugLevel );
@@ -245,6 +261,7 @@ void KVpncConfig::saveOptions()
 	config->writeEntry( "Kvpnc debuglevel", KvpncDebugLevel );
 	config->writeEntry( "Pppd debuglevel", PppdDebugLevel );
 	config->writeEntry( "Openvpn debuglevel", OpenvpnDebugLevel );
+	config->writeEntry( "Pptp debuglevel", PptpDebugLevel );
 	config->writeEntry( "Path to vpnc-bin", pathToVpnc );
 	config->writeEntry( "Path to racoon", pathToRacoon );
 	config->writeEntry( "Path to setkey", pathToSetkey );
@@ -252,6 +269,7 @@ void KVpncConfig::saveOptions()
 	config->writeEntry( "Path to openssl", pathToOpenssl );
 	config->writeEntry( "Path to freeswan", pathToFreeswan );
 	config->writeEntry( "Path to pppd", pathToPppd );
+	config->writeEntry( "Path to pptp", pathToPptp );
 	config->writeEntry( "Path to kill", pathToKill );
 	config->writeEntry( "Path to kill-all", pathToKillall );
 	config->writeEntry( "Path to ping", pathToPing );
@@ -275,6 +293,14 @@ void KVpncConfig::saveOptions()
 	config->writeEntry( "Auto connect profile", AutoConnectProfile );
 	config->writeEntry( "Do auto connect at startup", doAutoConnectAtStartup );
 	config->writeEntry( "Log viewer font size", LogViewerFontSize );
+  config->writeEntry( "Mainwindow width", parent->width() );
+  config->writeEntry( "Mainwindow height", parent->height() );
+  config->writeEntry( "Mainwindow position x", parent->x() );
+  config->writeEntry( "Mainwindow position y", parent->y() );
+	config->writeEntry( "hideOnCloseInfo" ,hideOnCloseInfo);
+//   config->writeEntry( "ToolBar Settings" ,parent->toolBar( "mainToolBar" ));
+	config->writeEntry("Use KWallet",useKwallet);
+	appPointer->processEvents();
 
 	if (useKwallet && KWallet::Wallet::isEnabled())
 		config->writeEntry( "First use of Kwallet", false );
@@ -284,6 +310,7 @@ void KVpncConfig::saveOptions()
 	{
 		for ( it = AccountList->first(); it; it = AccountList->next() )
 		{
+			appPointer->processEvents();
 			//std::cout << "Save profile: " << it->getName() << std::endl;
 			if ( !it->getName().isEmpty() )
 			{
@@ -297,120 +324,146 @@ void KVpncConfig::saveOptions()
 				/* passwords with kwallet */
 				if ( useKwallet && KWallet::Wallet::isEnabled())
 				{
-					if (KvpncDebugLevel > 0)
-						appendLogEntry(i18n( "Wallet enabled and available, writing to wallet." ),debug);
-					// Open local wallet
-					wallet = KWallet::Wallet::openWallet(KWallet::Wallet::LocalWallet());
-					if (wallet != 0)
+					if (!skipKwalletStoring )
 					{
-						QString walletname="kvpnc";
-						// Check if folder exists, otherwise create it
-						bool walletOK=true;
-						if (!wallet->hasFolder(walletname))
-							walletOK = wallet->createFolder(walletname);
-						if (walletOK)
+						if (KvpncDebugLevel > 0)
+							appendLogEntry(i18n( "Wallet enabled and available, writing to wallet." ),debug);
+						// Open local wallet
+						wallet = KWallet::Wallet::openWallet(KWallet::Wallet::LocalWallet());
+						appPointer->processEvents();
+						if (wallet != 0)
 						{
-							wallet->setFolder(walletname);
-							//std::cout << "[set] account: " << ProfileName << ", loginname: " << loginname << ", password: " << pwd << std::endl;
-							bool UserPasswordOK=true;
-							if ( it->getSaveUserPassword() )
-								UserPasswordOK = (wallet->writePassword (QString(name+"__user_pw"), it->getUserPassword()) == 0);
-							else
-								UserPasswordOK = (wallet->writePassword (QString(name+"__user_pw"), "") == 0);
-							bool PskOK=true;
-							if ( it->getSavePsk() )
-								PskOK = (wallet->writePassword (QString(name+"__psk"), it->getPreSharedKey()) == 0);
-							else
-								PskOK = (wallet->writePassword (QString(name+"__psk"), "") == 0);
-
-							bool PskKeyPassOK = (wallet->writePassword (QString(name+"__priv_key_pwd"), it->getPrivateKeyPass()) == 0);
-
-							if (KvpncDebugLevel > 0)
+							QString walletname="kvpnc";
+							// Check if folder exists, otherwise create it
+							bool walletOK=true;
+							if (!wallet->hasFolder(walletname))
 							{
-								if (UserPasswordOK)
-									appendLogEntry(i18n( "write of %1 was ok." ).arg(i18n("user password")), debug);
+								walletOK = wallet->createFolder(walletname);
+								appPointer->processEvents();
+							}
+							if (walletOK)
+							{
+								wallet->setFolder(walletname);
+								appPointer->processEvents();
+								//std::cout << "[set] account: " << ProfileName << ", loginname: " << loginname << ", password: " << pwd << std::endl;
+								bool UserPasswordOK=true;
+								if ( it->getSaveUserPassword() )
+									UserPasswordOK = (wallet->writePassword (QString(name+"__user_pw"), it->getUserPassword()) == 0);
 								else
-								{
-									// 									if ( KMessageBox::warningContinueCancel( 0,
-									// 									        i18n( "KVpnc is unable to save %1 password securely in your wallet.<br>"
-									// 									              "Do you want to save the password in the <b>unsafe</b> configuration file instead?" ).arg(i18n("user password")),
-									// 									        i18n( "Unable to store secure %1" ).arg(i18n("user password")),
-									// 									        KGuiItem( i18n( "Store &Unsafe" ), QString::fromLatin1( "unlock" ),QString::fromLatin1( "KWalletFallbackToKConfig" ) ) ) == KMessageBox::Continue )
-									// 									{
-									// 										config->writeEntry( "User password", it->getUserPassword() );
-									// 									}
+									UserPasswordOK = (wallet->writePassword (QString(name+"__user_pw"), "") == 0);
 
-									appendLogEntry(i18n( "write of %1 has failed." ).arg(i18n("user password")), debug);
-								}
+								appPointer->processEvents();
 
-								if (PskOK)
-									appendLogEntry(i18n( "write of %1 was successful." ).arg(i18n("preshared key")), debug);
+								bool PskOK=true;
+								if ( it->getSavePsk() )
+									PskOK = (wallet->writePassword (QString(name+"__psk"), it->getPreSharedKey()) == 0);
 								else
-								{
-									// 									if ( KMessageBox::warningContinueCancel( 0,
-									// 									        i18n( "KVpnc is unable to save %1 password securely in your wallet.<br>"
-									// 									              "Do you want to save the password in the <b>unsafe</b> configuration file instead?" ).arg(i18n("pre shared key")),
-									// 									        i18n( "Unable to store secure %1" ).arg(i18n("pre shared key")),
-									// 									        KGuiItem( i18n( "Store &Unsafe" ), QString::fromLatin1( "unlock" ),QString::fromLatin1( "KWalletFallbackToKConfig" ) ) ) == KMessageBox::Continue )
-									// 									{
-									// 										config->writeEntry( "Pre shared key", it->getPreSharedKey() );
-									// 									}
-									appendLogEntry(i18n( "write of %1 has failed." ).arg(i18n("preshared key")),debug);
-								}
+									PskOK = (wallet->writePassword (QString(name+"__psk"), "") == 0);
 
-								if (PskOK)
-									appendLogEntry(i18n( "write of %1 was successful." ).arg(i18n("preshared key")), debug);
-								else
+								appPointer->processEvents();
+
+								bool PskKeyPassOK = (wallet->writePassword (QString(name+"__priv_key_pwd"), it->getPrivateKeyPass()) == 0);
+
+								appPointer->processEvents();
+
+								if (KvpncDebugLevel > 0)
 								{
-									// 									if ( KMessageBox::warningContinueCancel( 0,
-									// 									        i18n( "KVpnc is unable to save %1 password securely in your wallet.<br>"
-									// 									              "Do you want to save the password in the <b>unsafe</b> configuration file instead?" ).arg(i18n("preshared key password")),
-									// 									        i18n( "Unable to store secure %1" ).arg(i18n("reshared key password")),
-									// 									        KGuiItem( i18n( "Store &Unsafe" ), QString::fromLatin1( "unlock" ),QString::fromLatin1( "KWalletFallbackToKConfig" ) ) ) == KMessageBox::Continue )
-									// 									{
-									// 										config->writeEntry( "Pre shared key", it->getPreSharedKey() );
-									// 									}
-									appendLogEntry(i18n( "write of %1 has failed." ).arg(i18n("preshared key")),debug);
+									if (UserPasswordOK)
+										appendLogEntry(i18n( "write of %1 was ok." ).arg(i18n("user password")), debug);
+									else
+									{
+										// 									if ( KMessageBox::warningContinueCancel( 0,
+										// 									        i18n( "KVpnc is unable to save %1 password securely in your wallet.<br>"
+										// 									              "Do you want to save the password in the <b>unsafe</b> configuration file instead?" ).arg(i18n("user password")),
+										// 									        i18n( "Unable to store secure %1" ).arg(i18n("user password")),
+										// 									        KGuiItem( i18n( "Store &Unsafe" ), QString::fromLatin1( "unlock" ),QString::fromLatin1( "KWalletFallbackToKConfig" ) ) ) == KMessageBox::Continue )
+										// 									{
+										// 										config->writeEntry( "User password", it->getUserPassword() );
+										// 									}
+
+										appendLogEntry(i18n( "write of %1 has failed." ).arg(i18n("user password")), debug);
+									}
+
+									if (PskOK)
+										appendLogEntry(i18n( "write of %1 was successful." ).arg(i18n("preshared key")), debug);
+									else
+									{
+										// 									if ( KMessageBox::warningContinueCancel( 0,
+										// 									        i18n( "KVpnc is unable to save %1 password securely in your wallet.<br>"
+										// 									              "Do you want to save the password in the <b>unsafe</b> configuration file instead?" ).arg(i18n("pre shared key")),
+										// 									        i18n( "Unable to store secure %1" ).arg(i18n("pre shared key")),
+										// 									        KGuiItem( i18n( "Store &Unsafe" ), QString::fromLatin1( "unlock" ),QString::fromLatin1( "KWalletFallbackToKConfig" ) ) ) == KMessageBox::Continue )
+										// 									{
+										// 										config->writeEntry( "Pre shared key", it->getPreSharedKey() );
+										// 									}
+										appendLogEntry(i18n( "write of %1 has failed." ).arg(i18n("preshared key")),debug);
+									}
+
+									if (PskOK)
+										appendLogEntry(i18n( "write of %1 was successful." ).arg(i18n("preshared key")), debug);
+									else
+									{
+										// 									if ( KMessageBox::warningContinueCancel( 0,
+										// 									        i18n( "KVpnc is unable to save %1 password securely in your wallet.<br>"
+										// 									              "Do you want to save the password in the <b>unsafe</b> configuration file instead?" ).arg(i18n("preshared key password")),
+										// 									        i18n( "Unable to store secure %1" ).arg(i18n("reshared key password")),
+										// 									        KGuiItem( i18n( "Store &Unsafe" ), QString::fromLatin1( "unlock" ),QString::fromLatin1( "KWalletFallbackToKConfig" ) ) ) == KMessageBox::Continue )
+										// 									{
+										// 										config->writeEntry( "Pre shared key", it->getPreSharedKey() );
+										// 									}
+										appendLogEntry(i18n( "write of %1 has failed." ).arg(i18n("preshared key")),debug);
+									}
+									if (PskKeyPassOK)
+										appendLogEntry(i18n( "write of %1 was successful." ).arg(i18n("preshared key password")), debug);
+									else
+									{
+										// 									if ( KMessageBox::warningContinueCancel( 0,
+										// 									        i18n( "KVpnc is unable to save %1 password securely in your wallet.<br>"
+										// 									              "Do you want to save the password in the <b>unsafe</b> configuration file instead?" ).arg(i18n("preshared key password")),
+										// 									        i18n( "Unable to store secure %1" ).arg(i18n("reshared key password")),
+										// 									        KGuiItem( i18n( "Store &Unsafe" ), QString::fromLatin1( "unlock" ),QString::fromLatin1( "KWalletFallbackToKConfig" ) ) ) == KMessageBox::Continue )
+										// 									{
+										// 										config->writeEntry( "Pre shared key", it->getPreSharedKey() );
+										// 									}
+										appendLogEntry(i18n( "write of %1 has failed." ).arg(i18n("preshared key password")),debug);
+									}
+									//std::cout << "success: " << pwdOK << std::endl;
 								}
-								if (PskKeyPassOK)
-									appendLogEntry(i18n( "write of %1 was successful." ).arg(i18n("preshared key password")), debug);
-								else
-								{
-									// 									if ( KMessageBox::warningContinueCancel( 0,
-									// 									        i18n( "KVpnc is unable to save %1 password securely in your wallet.<br>"
-									// 									              "Do you want to save the password in the <b>unsafe</b> configuration file instead?" ).arg(i18n("preshared key password")),
-									// 									        i18n( "Unable to store secure %1" ).arg(i18n("reshared key password")),
-									// 									        KGuiItem( i18n( "Store &Unsafe" ), QString::fromLatin1( "unlock" ),QString::fromLatin1( "KWalletFallbackToKConfig" ) ) ) == KMessageBox::Continue )
-									// 									{
-									// 										config->writeEntry( "Pre shared key", it->getPreSharedKey() );
-									// 									}
-									appendLogEntry(i18n( "write of %1 has failed." ).arg(i18n("preshared key password")),debug);
-								}
-								//std::cout << "success: " << pwdOK << std::endl;
+								appPointer->processEvents();
+							}
+							else
+							{
+								KMessageBox::error( 0, i18n( "Unable to create wallet folder for kvpnc!" ) );
+								appendLogEntry(i18n( "Unable to create wallet folder for kvpnc!" ), error);
 							}
 						}
-						else
-						{
-							KMessageBox::error( 0, i18n( "Unable to create wallet folder for kvpnc!" ) );
-							appendLogEntry(i18n( "Unable to create wallet folder for kvpnc!" ), error);
-						}
 					}
-				}
-				else
-				{
+					else //sessionSaving neither writing to wallet nor to config-file
+					{
 					if (KvpncDebugLevel > 0)
-						appendLogEntry(i18n( "Wallet disabled or not available, writing to config file." ),debug);
-					// write passwords to config file :|
-					if ( it->getSaveUserPassword() )
-					{
-						config->writeEntry( "User password", it->getUserPassword() );
+							appendLogEntry(i18n( "Writing into Wallet is not possible at shutdown, skipping." ),debug);
 					}
-					if ( it->getSavePsk() )
-					{
-						config->writeEntry( "Pre shared key", it->getPreSharedKey() );
-					}
-					config->writeEntry( "PrivateKey password", it->getPrivateKeyPass() );
 				}
+				else//Wallet not available
+				{
+					//if (!useKwallet)
+					{
+						if (KvpncDebugLevel > 0)
+							appendLogEntry(i18n( "Wallet disabled or not available, writing to config file." ),debug);
+						// write passwords to config file :|
+						if ( it->getSaveUserPassword() )
+						{
+							config->writeEntry( "User password", it->getUserPassword() );
+						}
+						if ( it->getSavePsk() )
+						{
+							config->writeEntry( "Pre shared key", it->getPreSharedKey() );
+						}
+						config->writeEntry( "PrivateKey password", it->getPrivateKeyPass() );
+					}
+				}
+
+				appPointer->processEvents();
 
 				// normal config
 				if ( it->getConnectionType() == VpnAccountData::cisco )
@@ -435,6 +488,7 @@ void KVpncConfig::saveOptions()
 				config->writeEntry( "Use advanced settings", it->getUseAdvancedSettings() );
 				config->writeEntry( "Application version", it->getApplicationVersion() );
 				config->writeEntry( "Local port", it->getLocalPort() );
+				config->writeEntry( "Remote port", it->getRemotePort() );
 				config->writeEntry( "NT domain name", it->getNtDomainName() );
 				config->writeEntry( "Perfect forward secrety", it->getPerfectForwardSecrety() );
 				config->writeEntry( "IKE group", it->getIkeGroup() );
@@ -442,13 +496,12 @@ void KVpncConfig::saveOptions()
 				config->writeEntry( "Use global IPSec secret", it->getUseGlobalIpsecSecret() );
 				config->writeEntry( "Use IKE group", it->getUseIkeGroup() );
 				config->writeEntry( "Use local port", it->getUseLocalPort() );
+				config->writeEntry( "Use remote port", it->getUseRemotePort() );
 				config->writeEntry( "Use NT domain name", it->getUseNtDomainName() );
 				config->writeEntry( "Use single DES", it->getUseSingleDes() );
 				config->writeEntry( "Use perfect Forward Secrety", it->getUsePerfectForwardSecrety() );
-				QString RemoteNetAddr = it->getRemoteNet().section( '/', 0, 0 );
-				QString RemoteNetMask = it->getRemoteNet().section( '/', 1, 1 );
-				config->writeEntry( "Remote net address", RemoteNetAddr );
-				config->writeEntry( "Remote net mask", RemoteNetMask );
+				config->writeEntry( "Remote net address", it->getRemoteNetAddr() );
+				config->writeEntry( "Remote net mask", it->getRemoteNetMask() );
 
 				config->writeEntry( "x509 certificate", it->getX509Certificate() );
 				config->writeEntry( "Ca certificate", it->getCaCertificate() );
@@ -461,6 +514,7 @@ void KVpncConfig::saveOptions()
 				config->writeEntry( "do ping ip", it->getDoPingIP() );
 				config->writeEntry( "Ping host IP", it->getPingHostIP() );
 
+				appPointer->processEvents();
 
 				config->writeEntry( "Use special remote ID", it->getUseSpecialRemoteID() );
 				config->writeEntry( "Special server certificate", it->getSpecialServerCertificate() );
@@ -514,6 +568,32 @@ void KVpncConfig::saveOptions()
 				config->writeEntry( "Disable LZO compression", it->getDisableLzoCompression());
 				config->writeEntry( "AuthWithUsernameAndPassword", it->getAuthWithUsernameAndPassword() );
 				config->writeEntry( "AllowEmptyGroupPassword", it->getAllowEmptyGroupPassword() );
+				config->writeEntry( "Use userdefinied cipher", it->getUseUserdefiniedCipher() );
+				config->writeEntry( "Userdefinied cipher", it->getUserdefiniedCipher() );
+				config->writeEntry( "Use redirect gateway", it->getUseRedirectGateway() );
+				config->writeEntry( "Use TLS auth", it->getUseTlsAuth() );
+				config->writeEntry( "TLS auth file", it->getTlsAuthFile() );
+				config->writeEntry( "Use HTTP proxy", it->getUseHttpProxy() );
+				config->writeEntry( "HTTP proxy host", it->getHttpProxy() );
+				config->writeEntry( "HTTP proxy port", it->getHttpProxyPort() );
+				config->writeEntry( "HTTP proxy timeout", it->getHttpProxyTimeout() );
+				config->writeEntry( "Dont save username", it->getDontSaveUsername() );
+				config->writeEntry( "Use mode config", it->getUseModeConfig() );
+				config->writeEntry( "Exchange mode", it->getExchangeMode() );
+				config->writeEntry( "Use delay at reconnect", it->getUseReconnectDelay() );
+				config->writeEntry( "Reconnect delay", it->getReconnectDelay() );
+				config->writeEntry( "Use TLS host", it->getUseTlsRemoteHost() );
+				config->writeEntry( "TLS remote host", it->getTlsRemoteHost() );
+				config->writeEntry( "Disable opportunistic encryption", it->getDisableOpportunisticEncryption() );
+				config->writeEntry( "Right next hop", it->getRightNextHop() );
+				config->writeEntry( "Left next hop", it->getLeftNextHop() );
+				config->writeEntry( "Use mssfix", it->getUseMssfix() );
+				config->writeEntry( "Use userdefinied packet size for fragmentation", it->getUseFragment() );
+				config->writeEntry( "Use userdef packet size", it->getMssfix() );
+				config->writeEntry( "Fragment", it->getFragment() );
+				config->writeEntry( "PeerTimeout", it->getPeerTimeout() );
+
+				appPointer->processEvents();
 
 				QString AdditionalNetworkRoutesString;
 				QStringList AdditionalNetworkRoutes = it->getAdditionalNetworkRoutes();
@@ -531,20 +611,26 @@ void KVpncConfig::saveOptions()
 				/* give info */
 				//slotStatusMsg ( i18n( "Profile \"%1\" saved." ).arg( ProfileName.remove("Profile_") ), ID_FLASH_MSG );
 				appendLogEntry ( i18n( "Profile \"%1\" saved." ).arg( ProfileName.remove("Profile_") ) , info);
+				appPointer->processEvents();
 			}
 		}
 	}
-
 	config->sync();
+	appPointer->processEvents();
 }
 
 void KVpncConfig::loadOptions()
 {
+	config->setGroup( "Notification Messages" );
+	hideOnCloseInfo = config->readBoolEntry( "hideOnCloseInfo" ,false);
+
 	config->setGroup( "General Options" );
 	minimizeAfterConnect = config->readBoolEntry( "Minimize after connect", true );
 	useSilentQuit = config->readBoolEntry( "Use silent quit", false );
 	dontQuitOnCloseEvent = config->readBoolEntry( "Dont quit on CloseEvent", true );
-	showDebugConsole = config->readBoolEntry( "Show debugconsole", false );
+	showDebugConsole = config->readBoolEntry( "Show debugconsole", true );
+	enableDebugPppd = config->readBoolEntry( "Enable pppd debug", false );
+	enableFreeswanVerbose = config->readBoolEntry( "Enable FreeSWAN verbose", false );
 	Vpnc_pid_file = config->readEntry( "Pid file for vpnc ", "/var/run/vpnc/pid" );
 	RacoonDebugLevel = config->readEntry( "Racoon debuglevel", "info" );
 	// we need to correct old int value
@@ -555,6 +641,7 @@ void KVpncConfig::loadOptions()
 	KvpncDebugLevel = config->readNumEntry( "Kvpnc debuglevel", 0 );
 	PppdDebugLevel = config->readBoolEntry( "Pppd debuglevel", false );
 	OpenvpnDebugLevel = config->readNumEntry( "Openvpn debuglevel", 0 );
+	PptpDebugLevel = config->readNumEntry( "Pptp debuglevel", 1 );
 	pathToVpnc = config->readEntry( "Path to vpnc-bin", "/usr/sbin/vpnc" );
 	pathToSetkey = config->readEntry( "Path to setkey", "/usr/sbin/setkey" );
 	pathToRacoon = config->readEntry( "Path to racoon", "/usr/sbin/racoon" );
@@ -565,6 +652,7 @@ void KVpncConfig::loadOptions()
 	pathToIfconfig = config->readEntry( "Path to ifconfig", "/sbin/ifconfig" );
 	pathToRoute = config->readEntry( "Path to route", "/sbin/route" );
 	pathToPppd = config->readEntry ("Path to pppd","/usr/sbin/pppd");
+	pathToPptp = config->readEntry ("Path to pptp","/usr/sbin/pptp");
 	pathToKill = config->readEntry ("Path to kill","/bin/kill");
 	pathToKillall = config->readEntry ("Path to kill-all","/usr/bin/killall");
 	pathToPing = config->readEntry ("Path to ping","/bin/ping");
@@ -591,10 +679,10 @@ void KVpncConfig::loadOptions()
 	doAutoConnectAtStartup = config->readBoolEntry( "Do auto connect at startup", false );
 	LogViewerFontSize = config->readNumEntry( "Log viewer font size", 2 );
 
-
 	WindowSize = QSize( config->readNumEntry( "Mainwindow width", 50 ), this->config->readNumEntry( "Mainwindow height", 50 ) );
 	WindowPos = QPoint ( config->readNumEntry( "Mainwindow position x", 10 ), this->config->readNumEntry( "Mainwindow position y", 50 ) );
 
+	appPointer->processEvents();
 
 	if ( writeLogFile )
 		if ( !logfile.isOpen() )
@@ -629,6 +717,7 @@ void KVpncConfig::loadOptions()
 			}
 		}
 
+	useKwallet = config->readBoolEntry("Use KWallet", true);
 	firstUseOfKwallet = config->readBoolEntry( "First use of Kwallet", true );
 
 	if ( KvpncDebugLevel > 0 )
@@ -720,6 +809,7 @@ void KVpncConfig::loadOptions()
 						KMessageBox::error( 0, i18n( "Unable to set wallet folder for kvpnc!" ) );
 						appendLogEntry(i18n( "Unable to set wallet folder for kvpnc!" ), error);
 					}
+					appPointer->processEvents();
 				}
 				else
 				{
@@ -770,6 +860,7 @@ void KVpncConfig::loadOptions()
 			data->setUseAdvancedSettings( config->readBoolEntry( "Use advanced settings", false ));
 			data->setApplicationVersion( config->readEntry( "Application version", "Cisco Systems VPN Client 0.3-rm+zomb.1:Linux" ));
 			data->setLocalPort( config->readNumEntry( "Local port", 500 ));
+			data->setRemotePort( config->readNumEntry( "Remote port", 500 ));
 			data->setNtDomainName( config->readEntry( "NT domain name", "" ));
 			data->setPerfectForwardSecrety( config->readEntry( "Perfect forward secrety", "server" ));
 			data->setIkeGroup( config->readEntry( "IKE group", "dh1" ));
@@ -777,11 +868,10 @@ void KVpncConfig::loadOptions()
 			data->setUseGlobalIpsecSecret( config->readBoolEntry( "Use global IPSec secret", false ));
 			data->setUseIkeGroup( config->readBoolEntry( "Use IKE group", false ));
 			data->setUseLocalPort( config->readBoolEntry( "Use local port", false ));
+			data->setUseRemotePort( config->readBoolEntry( "Use remote port", false ));
 			data->setUseNtDomainName( config->readBoolEntry( "Use NT domain name", false ));
 			data->setUseSingleDes( config->readBoolEntry( "Use single DES", false ));
 			data->setUsePerfectForwardSecrety( config->readBoolEntry( "Use perfect Forward Secrety", false ));
-			QString RemoteNetAddr = config->readEntry( "Remote net address", "" );
-			int RemoteNetMask = config->readNumEntry( "Remote net mask", 24 );
 			data->setX509Certificate( config->readEntry( "x509 certificate", "" ));
 			data->setCaCertificate( config->readEntry( "Ca certificate", "" ));
 			data->setNetworkDevice( config->readEntry( "Network device", "default" ));
@@ -794,6 +884,8 @@ void KVpncConfig::loadOptions()
 				authtype = VpnAccountData::psk;
 			data->setAuthType(authtype);
 
+			appPointer->processEvents();
+
 			data->setDoPingIP( config->readBoolEntry( "do ping ip", false ));
 			data->setPingHostIP( config->readEntry( "Ping host IP", "" ));
 			data->setUseSpecialRemoteID( config->readBoolEntry( "Use special remote ID", false ));
@@ -834,6 +926,7 @@ void KVpncConfig::loadOptions()
 			data->setVirtualIP( config->readEntry( "Virtual IP", "" ));
 			data->setPskIsInFile( config->readBoolEntry( "PSK is in file", false ));
 			data->setUseAdditionalNetworkRoutes(	config->readBoolEntry( "Use additional network routes", false ));
+			appPointer->processEvents();
 			QString AdditionalNetworkRoutesString = config->readEntry( "Additional network routes", "" );
 			// Networks delimited by a ','
 			QStringList AdditionalNetworkRoutes(QStringList::split( ",", AdditionalNetworkRoutesString ));
@@ -851,17 +944,40 @@ void KVpncConfig::loadOptions()
 			data->setDoReconnectAfterConnectionLost(config->readBoolEntry("Do reconnect after connection lost", false));
 			data->setDisableLzoCompression(config->readBoolEntry("Disable LZO compression", false));
 			data->setUserPassword( UserPassword );
-			data->setRemoteNet( RemoteNetAddr + "/" + QString().setNum( RemoteNetMask ) );
+			data->setRemoteNetAddr( config->readEntry("Remote net address","") );
+			data->setRemoteNetMask( QString().setNum(config->readNumEntry("Remote net mask",24 )));
 			data->setPreSharedKey( PreSharedKey );
 			data->setPrivateKeyPass( PrivateKeyPass );
 			data->setAuthWithUsernameAndPassword( config->readBoolEntry( "AuthWithUsernameAndPassword",false ) );
 			data->setAllowEmptyGroupPassword( config->readBoolEntry( "AllowEmptyGroupPassword", false ) );
+			data->setUseUserdefiniedCipher( config->readBoolEntry( "Use userdefinied cipher", false ) );
+			data->setUserdefiniedCipher( config->readEntry( "Userdefinied cipher", "" ) );
+			appPointer->processEvents();
+			data->setUseRedirectGateway( config->readBoolEntry( "Use redirect gateway", false ) );
+			data->setUseTlsAuth( config->readBoolEntry( "Use TLS auth", false ) );
+			data->setTlsAuthFile( config->readEntry( "TLS auth file", "" ) );
+			data->setUseHttpProxy( config->readBoolEntry( "Use HTTP proxy", false ) );
+			data->setHttpProxy( config->readEntry( "HTTP proxy host", "" ) );
+			data->setHttpProxyPort( config->readNumEntry( "HTTP proxy port", 8080 ) );
+			data->setHttpProxyTimeout( config->readNumEntry( "HTTP proxy timeout", 5 ) );
+			data->setDontSaveUsername( config->readBoolEntry( "Dont save username", false ) );
+			data->setUseModeConfig( config->readBoolEntry( "Use mode config", false ) );
+			data->setExchangeMode( config->readEntry( "Exchange mode", "main" ) );
+			data->setUseReconnectDelay( config->readBoolEntry( "Use delay at reconnect", false ) );
+			data->setReconnectDelay( config->readNumEntry( "Reconnect delay", 5 ) );
+			data->setUseTlsRemoteHost( config->readBoolEntry( "Use TLS host", false) );
+			data->setTlsRemoteHost( config->readEntry( "TLS remote host", "") );
+			data->setDisableOpportunisticEncryption( config->readBoolEntry( "Disable opportunistic encryption", false  ) );
+			data->setRightNextHop( config->readEntry( "Right next hop", "" ) );
+			data->setLeftNextHop( config->readEntry( "Left next hop", "" ) );
+			data->setUseMssfix(config->readBoolEntry( "Use userdef packet size", false) );
+			data->setUseFragment(config->readBoolEntry( "Use userdefinied packet size for fragmentation" , false) );
+			data->setMssfix(config->readNumEntry( "Mssfix", 1300) );
+			data->setFragment( config->readNumEntry( "Fragment", 1300) );
+			data->setPeerTimeout( config->readNumEntry( "PeerTimeout",0) );
 
-
+			appPointer->processEvents();
 			AccountList->append( data );
-
-			//ConnType, Name, Gateway, ID, GroupPassword, Username, UserPassword, saveUserPassword, saveGroupPassword, ApplicationVersion, Port, NtDomainName, PerfectForwardSecrecy, IkeGroup, useApplicationVersion, useGlobalIpsecSecret, useIkeGroup, useLocalPort, useNtDomainName, useSingleDes, useAdvancedSettings ) );
-
 		}
 
 		if ( name == "Client Options" )
@@ -900,6 +1016,8 @@ void KVpncConfig::loadOptions()
 
 			if ( KvpncDebugLevel > 0 )
 				appendLogEntry( i18n( "Configuration for profile \"%1\" loaded." ).arg( Name ),info );
+
+			appPointer->processEvents();
 		}
 
 
@@ -967,6 +1085,12 @@ void KVpncConfig::getToolsInfo()
 					it->addSearchPath(pathToPppd);
 				it->collectToolInfo();
 			}
+			else	if (it->Name == "pptp")
+			{
+				if (!pathToPptp.isEmpty())
+					it->addSearchPath(pathToPptp);
+				it->collectToolInfo();
+			}
 			else	if (it->Name == "iptables")
 			{
 				if (!pathToIptables.isEmpty())
@@ -1013,6 +1137,7 @@ void KVpncConfig::getToolsInfo()
 			{
 				std::cout << "Invalid tool!" << std::endl;
 			}
+			appPointer->processEvents();
 		}
 	}
 
@@ -1023,6 +1148,8 @@ void KVpncConfig::removeEntry(QString Name)
 	KStandardDirs * dirs = KGlobal::dirs();
 	QString filePath = dirs->findResource ( "config", "kvpncrc" );
 
+	appPointer->processEvents();
+
 	if (useKwallet && KWallet::Wallet::isEnabled())
 		config->deleteEntry( "First use of Kwallet", false );
 	/* = user data = */
@@ -1193,6 +1320,9 @@ void KVpncConfig::removeEntry(QString Name)
 					config->deleteEntry( "DNS server" );
 					config->deleteEntry( "get dns server from peer" );
 					config->deleteEntry( "refuse 40 bit encryption" );
+
+					appPointer->processEvents();
+
 					config->deleteEntry( "refuse 128 bit encryption" );
 					config->deleteEntry( "require stateless encryption" );
 					config->deleteEntry( "require mppe" );
@@ -1239,10 +1369,10 @@ void KVpncConfig::removeEntry(QString Name)
 				}
 			}
 		}
+		appPointer->processEvents();
 	}
 	config->sync();
+	appPointer->processEvents();
 }
 
-
-
 #include "kvpncconfig.moc"
