@@ -46,7 +46,7 @@ class KVpncConfig : public QObject
 {
 	Q_OBJECT
 public:
-	KVpncConfig();
+	KVpncConfig(QWidget *parent);
 	~KVpncConfig();
 
 public:
@@ -60,6 +60,7 @@ public:
 	QString pathToOpenssl;
 	QString pathToFreeswan;
 	QString pathToPppd;
+	QString pathToPptp;
 	QString pathToKill;
 	QString pathToKillall;
 	QString pathToPing;
@@ -82,6 +83,7 @@ public:
 	bool holdGeneratedScripts;
 	bool programsInPath;
 	bool enableDebugPppd;
+	bool enableFreeswanVerbose;
 	bool enableDebugOpenvpn;
 	bool useColorizedLogOutput;
 	bool showInterfaceIPinTooltip;
@@ -92,10 +94,14 @@ public:
 	bool showToolBar;
 	bool PppdDebugLevel;
 	bool firstUseOfKwallet; //< for importing passwords if there are stored before
+	bool shutdownIsCalled;
+	bool skipKwalletStoring; //< true if save should skip saving into kwallet
+	bool hideOnCloseInfo;
 
 	int VpncDebugLevel;
 	int KvpncDebugLevel;
 	int OpenvpnDebugLevel;
+	int PptpDebugLevel;
 	int LogViewerFontSize;
 	int mainwindow_pos_x;
 	int mainwindow_pos_y;
@@ -129,6 +135,8 @@ public:
 	QPoint WindowPos;
 	QSize WindowSize;
 
+	QWidget *parent;
+
 	/**
 	 * Appends a log enty to debug console and log file
 	 * @param msg the text to append
@@ -138,7 +146,7 @@ public:
 
 	/**
 	 *  Sets the output textedit for debug output
-	 * @param LogOutput 
+	 * @param LogOutput
 	 */
 	void setLogOutput(QTextEdit *LogOutput);
 
