@@ -36,14 +36,14 @@ QString currentdate ("+CVS("+QDate().currentDate().toString("yyyyMMdd")+QTime().
 #define __is_release__
 
 #ifdef __is_release__
-static const char *VERSION = "0.8.2.1";
+static const char *VERSION = "0.8.5.1";
 #else
-QString version = "0.8.2.1";
+QString version = "0.8.5.1";
 QString versionstring = version+currentdate;
 static const char *VERSION = versionstring.ascii() ;
 #endif
 
-	 
+
 static KCmdLineOptions options[] =
     {
         { 0, 0, 0 }
@@ -57,7 +57,7 @@ int main( int argc, char *argv[] ) {
 	                      "http://home.gna.org/kvpnc/", "crissi99@gmx.de" );
 
 	aboutData.addAuthor( "Christoph Thielecke", I18N_NOOP( "Developer and maintainer" ), "crissi99@gmx.de" );
-	
+
 	aboutData.addCredit("KDE Team" ,I18N_NOOP( "KDE"),"");
 	aboutData.addCredit("KDevelop Team" ,I18N_NOOP( "KDevelop"),"");
 	aboutData.addCredit("Maurice Massar" ,I18N_NOOP( "Vpnc"),"vpnc@unix-ag.uni-kl.de");
@@ -73,9 +73,11 @@ int main( int argc, char *argv[] ) {
 	aboutData.addCredit("Ahinu, Florian Fainelli, Damien Raude-Morvan" ,I18N_NOOP( "French translation"),"ahinu@wanadoo.fr, florian@alphacore.net,drazib@drazzib.com");
 	aboutData.addCredit("Marc Serra Romero" ,I18N_NOOP( "Catalan translation"),"mad93@majomo.com" );
 	aboutData.addCredit("Buelent SENER" ,I18N_NOOP( "Turkish  translation"),"bsener@inonu.edu.tr" );
-	aboutData.addCredit("Laurent Montel", I18N_NOOP( "Patches"), "montel@kde.org"); 
-	aboutData.addCredit("Peter Kussmann" ,I18N_NOOP( "Test environment, new ideas"),"peter.kussmann@gmx.de");
+	aboutData.addCredit("Laurent Montel", I18N_NOOP( "Patches"), "montel@kde.org");
+	aboutData.addCredit("Peter Kussmann" ,I18N_NOOP( "Test environment, OpenVPN testing, new ideas"),"peter.kussmann@gmx.de");
 	aboutData.addCredit("D. Klinkenberg" ,I18N_NOOP( "Testing PPTP, usebility hints & tests, bug hunting"),"d.klinkenberg@gmx.net");
+	aboutData.addCredit("Lenon Kitchens" ,I18N_NOOP( "Testing OpenSWAN, bug hunting"),"lenon@sanctuary.org");
+ 	aboutData.addCredit("Fathi Boudra" ,I18N_NOOP( "Testing OpenVPN, bug hunting"),"fboudra@free.fr");
 	aboutData.addCredit("HAL9000" ,I18N_NOOP( "Cisco password decoder"),"hal9000@evilscientists.de");
 
 	KCmdLineArgs::init( argc, argv, &aboutData );
@@ -90,7 +92,7 @@ int main( int argc, char *argv[] ) {
 	/*
 	if (getenv("USER") != "root"){
 		KMessageBox::error( 0, I18N_NOOP( "Kvpnc must be started as root!" ) );
-		exit(0);	
+		exit(0);
 	}
 	*/
 	KVpnc *kvpnc = new KVpnc(&a);
@@ -103,6 +105,6 @@ int main( int argc, char *argv[] ) {
 	kvpnc->show();
 
 	//  }
-
-	return a.exec();
+	int ret = a.exec();
+	return ret;
 }
