@@ -32,7 +32,7 @@
 
 /**
 Class for interaction with network interface
- 
+
 @author Christoph Thielecke
 */
 class NetworkInterface : public QObject
@@ -97,7 +97,7 @@ public:
 	 *     Gets the gateway of the default route
 	 * @return The interface
 	 */
-	QString getGatewayOfDefaultInterface(QString interface);
+	QString getGatewayOfDefaultInterface();
 
 	/**
 	 *    Gets the IP address which is used for communication with internet connections (same as local address if not behind router)
@@ -108,11 +108,32 @@ public:
 public slots:
 	void readFromStdout();
 	void readFromStderr();
+	void readFromStdout_interfaceExist();
+	void readFromStderr_interfaceExist();
+	void readFromStdout_getAllNetworkInterfaces();
+	void readFromStderr_getAllNetworkInterfaces();
+	void readFromStdout_defaultinterface();
+	void readFromStderr_defaultinterface();
+	void readFromStdout_interfaceip();
+	void readFromStderr_interfaceip();
+	void readFromStdout_gatewayofinterface();
+	void readFromStderr_gatewayofinterface();
+	void readFromStdout_gatewayofdefaultinterface();
+	void readFromStderr_gatewayofdefaultinterface();
+	void readFromStdout_interfaceaddress();
+	void readFromStderr_interfaceaddress();
 	void processHasFinished();
 	void externalIpDataRecieved(const QHttpResponseHeader & resp);
 
 protected:
 	QProcess *proc; //< The process for starting external programs
+	QProcess *DefaultInterfaceProc;
+	QProcess *InterfaceAddressProc;
+	QProcess *GatewayOfInterfaceProc;
+	QProcess *GatewayOfDefaultInterfaceProc;
+	QProcess *InterfaceIpProc;
+	QProcess *InterfaceExitsProc;
+	QProcess *GetAllNetworkInterfacesProc;
 	bool interfaceTest; //< True if interface test is running
 	bool retrieveAllNetworkInterfaces; //< True if retrieve all network interfaces is running
 	bool retrieveInterfaceIP; //< True if retrieve interface IP is running
@@ -124,6 +145,8 @@ protected:
 	QString InterfaceIP; //< IP for interface
 	QString InterfaceAddress; //< Device for IP
 	QString GatewayAddress; //< Gateway of Device
+	QString GatewayOfInterfaceAddress;
+	QString GatewayOfDefaultInterfaceAddress; //< Gateway of Device
 	bool interfaceExists; //< True if interface exists
 	QString ifconfigbin; //< Path to ifconfig
 	QString routebin; //< Path to route
@@ -136,7 +159,7 @@ protected:
 	QHttp *http;
 	QString ExternalIpAddress;
 	QStringList *env;
-	KVpncConfig *config;
+	KVpncConfig *GlobalConfig;
 };
 
 #endif
