@@ -138,6 +138,7 @@ NewProfileDialog::NewProfileDialog( QApplication *app,QWidget *parent, const QSt
 	main->NetworkDeviceComboBox->setCurrentText( "default" );
 
 	main->certpathURLRequester->setURL( "/etc/racoon/certs" );
+	main->certpathURLRequester->setMode( 2 ); // directory
 
 	main->ConnectionTypeComboBox->insertItem( i18n( "Cisco (vpnc)" ) );
 	main->ConnectionTypeComboBox->insertItem( i18n( "IPSec (racoon)" ) );
@@ -146,6 +147,8 @@ NewProfileDialog::NewProfileDialog( QApplication *app,QWidget *parent, const QSt
 	main->ConnectionTypeComboBox->insertItem( i18n( "OpenVPN" ) );
 	main->AuthTypeComboBox->setCurrentItem(1); // cisco
 
+	main->RemoteNetMaskComboBox->setCurrentText("24");
+
 	authTypeChanged( "" );
 	connectiontypeChanged( "" );
 }
@@ -202,7 +205,7 @@ void NewProfileDialog::accept()
 		}
 		else
 		{
-			if (!Utils(GlobalConfig).isValidIPv4Adress(main->RemoteNetAddrLineEdit->text()))
+			if (!Utils(GlobalConfig).isValidIPv4Address(main->RemoteNetAddrLineEdit->text()))
 			{
 
 				KMessageBox::error ( this, i18n( "IP address of remote network is not valid!" ), i18n( "Invalid IP Address" ) );
@@ -212,7 +215,8 @@ void NewProfileDialog::accept()
 			}
 			if ( validAddr )
 			{
-				profileData->setRemoteNet( main->RemoteNetAddrLineEdit->text() + "/" +  main->RemoteNetMaskComboBox->currentText() );
+				profileData->setRemoteNetAddr( main->RemoteNetAddrLineEdit->text());
+				profileData->setRemoteNetMask( main->RemoteNetMaskComboBox->currentText() );
 			}
 
 		}
