@@ -68,12 +68,13 @@ public:
 	 * @param LogOutput textedit for debug messages
 	 * @param GlobalConfig pointer to configuration object
 	 * @param showOnlyProfiles view mode. true: show as profile manager, false: show as preferences dialog
-	 * @return 
+	 * @return
 	 */
 	PreferencesDialog( QWidget *parent, QApplication *app,QTextEdit *LogOutput, KVpncConfig *GlobalConfig, bool showOnlyProfiles);
 
 public slots:
 	void accept();
+	void slotApply();
 	void authTypeChanged( int authtype );
 	void connectionTypeChanged( int connectiontype );
 	void profileChanged( const QString& itemtext );
@@ -83,6 +84,8 @@ public slots:
 	void newSessionClicked();
 	void importCertificate();
 	void pageChanged(QWidget *);
+	void userAuthToggled(bool);
+	void useUdpToggled(bool);
 
 protected:
 	void setupGui();
@@ -92,6 +95,7 @@ protected:
 	KVpncConfig *GlobalConfig;
 	QString lastProfileName;
 	int KvpncDebugLevel;
+	bool canAccept;
 
 public:
 	ProfileWidget *MyprofileWidget;
