@@ -143,6 +143,7 @@ void ProfileGeneralOptions::advancedSettingsClicked()
 
 		d1.main->IkeGroupCombobox->setEnabled (  GlobalConfig->currentProfile->getUseIkeGroup() );
 
+
 	}
 
 	d1.exec();
@@ -173,6 +174,34 @@ void ProfileGeneralOptions::useConnectionStatusCheckToggled()
 
 }
 
+void ProfileGeneralOptions::useReconnectDelayToggled(bool)
+{
+	if (UseReconnectDelayCheckBox->isChecked())
+		ReconnectDelayNumInput->setEnabled(true);
+	else
+		ReconnectDelayNumInput->setEnabled(false);
+}
+
+void ProfileGeneralOptions::useReconnectAfterDisconnectToggled(bool)
+{
+	if (DoReconnectAfterConnectionLostCheckBox->isChecked())
+	{
+			if (UseReconnectDelayCheckBox->isChecked())
+		ReconnectDelayNumInput->setEnabled(true);
+	else
+		ReconnectDelayNumInput->setEnabled(false);
+
+	UseReconnectDelayCheckBox->setEnabled(true);
+	}
+	else
+	{
+		ReconnectDelayNumInput->setEnabled(false);
+		UseReconnectDelayCheckBox->setEnabled(false);
+	}
+}
+
+
+
 
 
 
