@@ -397,10 +397,8 @@ if ( GlobalConfig->KvpncDebugLevel > 0 )
 
 		else if ( it->getConnectionType() == VpnAccountData::ConnectionType(VpnAccountData::racoon) || it->getConnectionType() == VpnAccountData::ConnectionType(VpnAccountData::freeswan ))
 		{
-			QString RemoteNetAddr = it->getRemoteNet().section( '/', 0, 0 );
-			QString RemoteNetMask = it->getRemoteNet().section( '/', 1, 1 );
-			RemoteNetAddrLineEdit->setText( RemoteNetAddr );
-			RemoteNetMaskComboBox->setCurrentText( RemoteNetMask );
+			RemoteNetAddrLineEdit->setText(  it->getRemoteNetAddr() );
+			RemoteNetMaskComboBox->setCurrentText(  it->getRemoteNetMask() );
 			if ( it->getAuthType() == VpnAccountData::cert )
 			{
 				AuthTypeComboBox->setCurrentItem( 0 );
@@ -483,12 +481,10 @@ if ( GlobalConfig->KvpncDebugLevel > 0 )
 			PingCheckBox->setChecked( it->getDoPingIP() );
 			PingIPLineEdit->setText( it->getPingHostIP() );
 
-			if (!it->getRemoteNet().isEmpty())
+			if (!it->getRemoteNetAddr().isEmpty() && !it->getRemoteNetMask().isEmpty())
 			{
-				QString RemoteNetAddr = it->getRemoteNet().section( '/', 0, 0 );
-				QString RemoteNetMask = it->getRemoteNet().section( '/', 1, 1 );
-				RemoteNetAddrLineEdit->setText( RemoteNetAddr );
-				RemoteNetMaskComboBox->setCurrentText( RemoteNetMask );
+				RemoteNetAddrLineEdit->setText( it->getRemoteNetAddr() );
+				RemoteNetMaskComboBox->setCurrentText( it->getRemoteNetMask() );
 			}
 
 			RefuseEapCheckbox->setChecked(it->getRefuseEap());
@@ -551,12 +547,10 @@ if ( GlobalConfig->KvpncDebugLevel > 0 )
 			LocalVirtualIpEdit->setText( it->getLocalVirtualIP());
 			RemoteVirtualIpLineEdit->setText( it->getRemoteVirtualIP());
 
-			if (!it->getRemoteNet().isEmpty())
+			if (!it->getRemoteNetAddr().isEmpty() && !it->getRemoteNetMask().isEmpty())
 			{
-				QString RemoteNetAddr = it->getRemoteNet().section( '/', 0, 0 );
-				QString RemoteNetMask = it->getRemoteNet().section( '/', 1, 1 );
-				RemoteNetAddrLineEdit->setText( RemoteNetAddr );
-				RemoteNetMaskComboBox->setCurrentText( RemoteNetMask );
+				RemoteNetAddrLineEdit->setText( it->getRemoteNetAddr() );
+				RemoteNetMaskComboBox->setCurrentText( it->getRemoteNetMask() );
 			}
 			RemoteNetMaskComboBox->setEnabled(true);
 			RemoteNetAddrLineEdit->setEnabled(true);
@@ -746,6 +740,8 @@ void ProfileWidget::connectionTypeChanged( int )
 		// 		buttonCancel->setEnabled( TRUE );
 		// 		buttonOk->setEnabled( TRUE );
 
+
+
 		OpenvpnGroupBox->setEnabled( true );
 		UseUdpCheckbox->setEnabled( true );
 		UdpPortCheckbox->setEnabled( true );
@@ -1043,7 +1039,8 @@ void ProfileWidget::saveSessionClicked()
 			}
 			if ( validAddr == true )
 			{
-				GlobalConfig->currentProfile->setRemoteNet( addr + "/" + RemoteNetMaskComboBox->currentText() );
+				GlobalConfig->currentProfile->setRemoteNetAddr( addr );
+				GlobalConfig->currentProfile->setRemoteNetMask( RemoteNetMaskComboBox->currentText() );
 			}
 
 		}
@@ -1109,14 +1106,16 @@ void ProfileWidget::saveSessionClicked()
 
 				if ( validAddr == true )
 				{
-					GlobalConfig->currentProfile->setRemoteNet( addr + "/" + RemoteNetMaskComboBox->currentText() );
+					GlobalConfig->currentProfile->setRemoteNetAddr( addr );
+					GlobalConfig->currentProfile->setRemoteNetMask( RemoteNetMaskComboBox->currentText() );
 				}
 
 			}
 		}
 		else
 		{
-			GlobalConfig->currentProfile->setRemoteNet("");
+			GlobalConfig->currentProfile->setRemoteNetAddr("");
+			GlobalConfig->currentProfile->setRemoteNetMask("");
 		}
 
 	}
@@ -1154,7 +1153,8 @@ void ProfileWidget::saveSessionClicked()
 			}
 			if ( validAddr == true )
 			{
-				GlobalConfig->currentProfile->setRemoteNet( addr + "/" + RemoteNetMaskComboBox->currentText() );
+				GlobalConfig->currentProfile->setRemoteNetAddr( addr );
+				GlobalConfig->currentProfile->setRemoteNetMask( RemoteNetMaskComboBox->currentText() );
 			}
 
 		}
@@ -1201,7 +1201,7 @@ void ProfileWidget::saveSessionClicked()
 	if ( PingCheckBox->isChecked() && !PingIPLineEdit->text().isEmpty() )
 	{
 		// do check for vailid IP
-		if (!Utils( GlobalConfig ).isValidIPv4Adress(PingIPLineEdit->text())) {
+		if (!Utils( GlobalConfig ).isValidIPv4Address(PingIPLineEdit->text())) {
 			KMessageBox::error ( this, i18n( "No valid IP address entered!" ), i18n( "No Valid IP Address" ) );
 			GlobalConfig->appendLogEntry( i18n( "No valid IP address entered!" ) ,GlobalConfig->error);
 		}
@@ -1228,7 +1228,7 @@ void ProfileWidget::saveSessionClicked()
 		if ( UseVirtualIPCheckBox->isChecked() && !LocalVirtualIpEdit->text().isEmpty() )
 		{
 			// do check for vailid IP
-			if (!Utils( GlobalConfig ).isValidIPv4Adress(LocalVirtualIpEdit->text())) {
+			if (!Utils( GlobalConfig ).isValidIPv4Address(LocalVirtualIpEdit->text())) {
 				KMessageBox::error ( this, i18n( "No valid IP address entered!" ), i18n( "No Valid IP Address" ) );
 				GlobalConfig->appendLogEntry( i18n( "No valid IP address entered!" ) ,GlobalConfig->error);
 			}
