@@ -47,7 +47,6 @@ ToolInfo::ToolInfo(const QString &Name)
 	Version=i18n("No info");
 }
 
-
 bool ToolInfo::collectToolInfo()
 {
 	bool success=false;
@@ -112,6 +111,8 @@ bool ToolInfo::collectToolInfo()
 			CollectToolInfoProcess->addArgument("-V");
 		else	if (Name == "route")
 			CollectToolInfoProcess->addArgument("-V");
+		else	if (Name == "pptp")
+			;
 		else
 		{
 			std::cout << "Invalid tool (" << Name.ascii() <<")!" << std::endl;
@@ -176,10 +177,10 @@ void ToolInfo::readStdOutCollectToolInfo()
 		}
 		else	if (Name == "ipsec")
 		{
-			if ( msg.find( "version", 0, FALSE ) > -1 )
+			if ( msg.find( "wan", 0, FALSE ) > -1 )
 			{
-				//std::cout << "stdout collectToolInfo: " << msg << std::endl;
-				Version = msg.section(' ',2,2);
+// 				std::cout << "stdout collectToolInfo: " << msg << std::endl;
+				Version = msg.section(' ',1,2);
 			}
 		}
 		else	if (Name == "racoon")
@@ -307,6 +308,14 @@ void ToolInfo::readStdErrCollectToolInfo()
 				Version = msg.section(' ',1,1);
 			}
 		}
+		else	if (Name == "pptp")
+		{
+			if ( msg.find( "pptp version", 0, FALSE ) > -1 )
+			{
+//				std::cout << "stdout collectToolInfo: " << msg.ascii() << std::endl;
+				Version = msg.section(' ',2,2).section(')',0,0);
+			}
+		}
 	}
 }
 
