@@ -103,7 +103,13 @@ ToolsInfoDialog::ToolsInfoDialog(KVpncConfig *GlobalConfig, QWidget *parent, con
 				tool->addSearchPath(GlobalConfig->pathToPppd.section('/',0,-2));
 				tool->collectToolInfo();
 			}
-
+		}
+		else	if (tool->Name == "pptp")
+		{
+			if (!GlobalConfig->pathToPptp.isEmpty()) {
+				tool->addSearchPath(GlobalConfig->pathToPptp.section('/',0,-2));
+				tool->collectToolInfo();
+			}
 		}
 		else	if (tool->Name == "iptables")
 		{
@@ -181,12 +187,21 @@ ToolsInfoDialog::ToolsInfoDialog(KVpncConfig *GlobalConfig, QWidget *parent, con
 					comment=i18n("no NAT-T, IPSec over IP, no split DNS support");
 				}
 			}
-			else if (tool->Name == "freeswan")
+			else if (tool->Name == "ipsec")
 			{
-				if ( tool->Version.find("2.",0,-1) > -1)
+				// version is like this: Openswan U2.4.4/K2.6.15.
+				QString realversion=tool->Version.section(' ',1,1).section('/',0,0).right(tool->Version.section(' ',1,1).section('/',0,0).length()-1);
+				QString realtype=tool->Version.section(' ',0,0).lower();
+
+				if ( realversion.find("2.",0,-1) > -1)
 					usability=i18n("full");
-				else if ( tool->Version.find("1.",0,-1) > -1)
+				else if ( realversion.find("1.",0,-1) > -1)
+				{
 					usability=i18n("limited");
+					comment=i18n("no aggressive mode");
+				}
+				else
+					usability=i18n("unknown");
 			}
 			else if (tool->Name == "racoon")
 			{
@@ -210,6 +225,13 @@ ToolsInfoDialog::ToolsInfoDialog(KVpncConfig *GlobalConfig, QWidget *parent, con
 				//else if ( tool->Version.find("2.",0,-1) > -1)
 				//	usability=i18n("limited");
 			}
+			else if (tool->Name == "pptp")
+			{
+				//if ( tool->Version.find("2.",0,-1) > -1)
+				usability=i18n("full");
+				//else if ( tool->Version.find("2.",0,-1) > -1)
+				//	usability=i18n("limited");
+			}
 			else if (tool->Name == "kill")
 			{
 				//if ( tool->Version.find("2.",0,-1) > -1)
@@ -257,9 +279,10 @@ ToolsInfoDialog::ToolsInfoDialog(KVpncConfig *GlobalConfig, QWidget *parent, con
 		main->InfoListView->insertItem(item);
 
 	}
+	this->resize(800,600);
 	main->InfoListView->resize(main->InfoListView->sizeHint());
 	main->resize(main->sizeHint());
-	this->resize(sizeHint());
+	//this->resize(sizeHint());
 
 	setCursor(Qt::ArrowCursor );
 }
