@@ -45,11 +45,15 @@ public:
 
 	~Utils();
 
-	bool isValidIPv4Adress(QString Address);
+	bool isValidIPv4Address(QString Address);
+	bool isValidIPv4NetworkAddress(QString Address);
+	bool isValidIPv4BroadcastAddress(QString Address);
 	bool tunDevExists();
 	bool createTunDev();
   bool loadKernelModule(QString Name,QApplication *app);
 	bool isValidNetworkDevice(QString NetworkDevice);
+	bool doChmod(QString file, QString mode);
+	QStringList getOpenvpnCiphers();
 	QPtrList<ToolInfo>* getToolList();
 	ToolInfo* getToolInfo(KVpncConfig *GlobalConfig, QString name);
 	QString resolveName(QString Name,QApplication *app);
@@ -64,6 +68,8 @@ public slots:
 	void readStdErrLoadKernelModule();
 	void readStdOutToolsTest();
 	void readStdErrToolsTest();
+	void readStdOutRetriveOpenvpnCiphers();
+	void readStdErrRetriveOpenvpnCiphers();
 	void dnsLookupHelper();
 	void processHasFinished();
 
@@ -71,11 +77,13 @@ private:
 	bool validNetworkDevice;
 	bool modprobeSuccess;
 	bool toolsTestSuccess;
+	bool retrieveOpenvpnCiphers;
 	QString tooltest_logfile;
 	QProcess *ModprobeProcess;
 	QProcess *createProcess;
 	QProcess *NetworkDeviceTestProcess;
 	QProcess *toolsTestProcess;
+	QProcess *OpenvpnCiphersProcess;
 	QString resolvedIP;
 	bool resolveFinished;
 	QDns *myDns;
@@ -84,6 +92,7 @@ private:
 	KVpncConfig *config;
 	KTempFile *tmpfile;
 	bool retrieveValidNetworkdevice;
+	QStringList OpenvpnCiphers;
 
 };
 
