@@ -21,7 +21,8 @@
 
 VpnAccountData::VpnAccountData( ConnectionType ConnType,const QString& Name)
 {
-	this->RemoteNet = "";
+	this->RemoteNetAddr = "";
+	this->RemoteNetMask = "24";
 	this->CertPath = "";
 	this->doPingIP = false;
 	this->pingHostIP = "";
@@ -39,7 +40,8 @@ VpnAccountData::VpnAccountData( ConnectionType ConnType,const QString& Name)
 	PerfectForwardSecrecy="";
 	NtDomainName="";
 	ApplicationVersion="";
-	RemoteNet="";
+	RemoteNetAddr="";
+	RemoteNetMask="";
 	PreSharedKey="";
 	x509Certificate="";
 	CaCertificate="";
@@ -67,11 +69,8 @@ VpnAccountData::VpnAccountData( ConnectionType ConnType,const QString& Name)
 	useGlobalIpsecSecret=false;
 	doPingIP=false;
 	useSpecialRemoteID=false;
-	LocalPort=500;
-	UserdefinedPort=10000;
 	useUdp=true;
 	useUdpPort=false;
-	UdpPort=4500;
 	useDnsServer=false;
 	DnsServer="";
 	useGetDnsFromPeer=true;
@@ -81,9 +80,7 @@ VpnAccountData::VpnAccountData( ConnectionType ConnType,const QString& Name)
 	requireMppe=true;
 	refuseEap=false;
 	useNoIpDefault=false;
-	;
 	disableMPPEComp=false;
-	;
 	executeCmdBeforeConnect=false;
 	executeCmdAfterConnect=false;
 	executeCmdBeforeDisconnect=false;
@@ -97,17 +94,87 @@ VpnAccountData::VpnAccountData( ConnectionType ConnType,const QString& Name)
 	setDefaultRoute=false;
 	replaceDefaultRoute=false;
 	useMtu=false;
-	Mtu=1500;
 	useVirtualIP=false;
 	VirtualIP="";
 	PskIsInFile=false;
 	useAdditionalNetworkRoutes=false;
-
+	useUserdefinedPort = false;
 	SpecialServerCertificate="";
 	useSpecialServerCertificate=false;
 	TunnelDeviceType="tun";
 	keepDefaultRoute = false;
 	allowEmptyGroupPassword=false;
+	useReconnectDelay=false;
+	useHttpProxy=false;
+	PskIsInFile=false;
+	RemoteNetMask="24";
+	RemoteNetAddr="";
+	saveUserPassword=true;
+	savePsk=true;
+	useAdvancedSettings=false;
+	useIkeGroup=false;
+	usePerfectForwardSecrety=false;
+	useNtDomainName=false;
+	useApplicationVersion=false;
+	useLocalPort=false;
+	useRemotePort=false;
+	useSingleDes=false;
+	useGlobalIpsecSecret=false;
+	doPingIP=false;
+	useSpecialRemoteID=false;
+	useUdp=false;
+	useUdpPort=false;
+	useDnsServer=false;
+	useGetDnsFromPeer=true;
+	refuse40BitEncryption=false;
+	refuse128BitEncryption=false;
+	allowStatefulMode=false;
+	requireMppe=true;
+	refuseEap=false;
+	useNoIpDefault=false;
+	disableMPPEComp=false;
+	executeCmdBeforeConnect=false;
+	executeCmdAfterConnect=false;
+	executeCmdBeforeDisconnect=false;
+	executeCmdAfterDisconnect=false;
+	useNoBsdComp=false;
+	useNoDeflate=false;
+	setDefaultRoute=false;
+	replaceDefaultRoute=false;
+	useMtu=false;
+	useVirtualIP=false;
+	PskIsInFile=false;
+	useAdditionalNetworkRoutes=false;
+	useSpecialServerCertificate=false;
+	useUserdefinedPort=false;
+	keepDefaultRoute=false;
+	useNsCertType=false;
+	useConnectionStatusCheck=true;
+	doReconnectAfterConnectionLost=true;
+	disableLzoCompression=false;
+	authWithUsernameAndPassword=false;
+	allowEmptyGroupPassword=false;
+	useUserdefiniedCipher=false;
+	useRedirectGateway=false;
+	useTlsAuth=false;
+	useTlsRemoteHost=false;
+	dontSaveUsername=false;
+	disableLzoCompression=false;
+	disableOpportunisticEncryption=false;
+	useMssfix=false;
+	useFragment=false;
+
+	ReconnectDelay=5;
+	connectionStatusInterval=20;
+	Mtu=1500;
+	LocalPort=500;
+	UserdefinedPort=10000;
+	UdpPort=4500;
+	HttpProxyPort=3128;
+	HttpProxyTimeout=100;
+	Mssfix=1300;
+	Fragment=1300;
+
 }
 
 
@@ -129,7 +196,7 @@ QString VpnAccountData::getGateway() const
 	return Gateway;
 }
 
-QString VpnAccountData::getID() const 
+QString VpnAccountData::getID() const
 {
 	return ID;
 }
@@ -139,7 +206,7 @@ QString VpnAccountData::getTunnelDeviceType() const
 	return TunnelDeviceType;
 }
 
-QString VpnAccountData::getUserName() const 
+QString VpnAccountData::getUserName() const
 {
 	return Username;
 }
@@ -204,11 +271,17 @@ bool VpnAccountData::getUseApplicationVersion() const
 {
 	return useApplicationVersion;
 }
+
 bool VpnAccountData::getUseLocalPort() const
 {
 	return useLocalPort;
 }
 
+bool VpnAccountData::getUseRemotePort() const
+{
+	return useRemotePort;
+}
+
 bool VpnAccountData::getUseAdvancedSettings() const
 {
 	return useAdvancedSettings;
@@ -224,9 +297,19 @@ int VpnAccountData::getLocalPort() const
 	return LocalPort;
 }
 
-QString VpnAccountData::getRemoteNet() const
+int VpnAccountData::getRemotePort() const
 {
-	return RemoteNet;
+	return RemotePort;
+}
+
+QString VpnAccountData::getRemoteNetAddr() const
+{
+	return RemoteNetAddr;
+}
+
+QString VpnAccountData::getRemoteNetMask() const
+{
+	return RemoteNetMask;
 }
 
 QString VpnAccountData::getPreSharedKey() const
@@ -371,6 +454,7 @@ QString VpnAccountData::getLocalVirtualIP() const
 {
 	return LocalVirtualIP;
 }
+
 QString VpnAccountData::getRemoteVirtualIP() const
 {
 	return RemoteVirtualIP;
@@ -381,7 +465,7 @@ QString VpnAccountData::getPreSharedKeyFile() const
 	return PreSharedKeyFile;
 }
 
-bool VpnAccountData::getExecuteCmdBeforeConnect() const 
+bool VpnAccountData::getExecuteCmdBeforeConnect() const
 {
 	return executeCmdBeforeConnect;
 }
@@ -538,7 +622,7 @@ bool VpnAccountData::getDisableLzoCompression() const
 
 bool VpnAccountData::getAuthWithUsernameAndPassword() const
 {
-		return AuthWithUsernameAndPassword;
+		return authWithUsernameAndPassword;
 }
 
 bool VpnAccountData::getAllowEmptyGroupPassword() const
@@ -546,6 +630,125 @@ bool VpnAccountData::getAllowEmptyGroupPassword() const
 	return allowEmptyGroupPassword;
 }
 
+bool VpnAccountData::getUseUserdefiniedCipher() const
+{
+	return useUserdefiniedCipher;
+}
+
+QString VpnAccountData::getUserdefiniedCipher() const
+{
+	return UserdefiniedCipher;
+}
+
+bool VpnAccountData::getUseRedirectGateway() const
+{
+	return useRedirectGateway;
+}
+
+bool VpnAccountData::getUseTlsAuth() const
+{
+	return useTlsAuth;
+}
+
+QString VpnAccountData::getTlsAuthFile() const
+{
+	return TlsAuthFile;
+}
+
+QString VpnAccountData::getHttpProxy() const
+{
+	return HttpProxy;
+}
+
+bool VpnAccountData::getUseHttpProxy() const
+{
+	return useHttpProxy;
+}
+
+int VpnAccountData::getHttpProxyPort() const
+{
+	return HttpProxyPort;
+}
+
+int VpnAccountData::getHttpProxyTimeout() const
+{
+	return HttpProxyTimeout;
+}
+
+bool VpnAccountData::getDontSaveUsername() const
+{
+	return dontSaveUsername;
+}
+
+bool VpnAccountData::getUseModeConfig() const
+{
+	return useModeConfig;
+}
+
+QString VpnAccountData::getExchangeMode() const
+{
+	return ExchangeMode;
+}
+
+bool VpnAccountData::getUseReconnectDelay() const
+{
+	return useReconnectDelay;
+}
+
+int VpnAccountData::getReconnectDelay() const
+{
+	return ReconnectDelay;
+}
+
+bool VpnAccountData::getUseTlsRemoteHost() const
+{
+	return useTlsRemoteHost;
+}
+
+QString VpnAccountData::getTlsRemoteHost() const
+{
+	return TlsRemoteHost;
+}
+
+QString VpnAccountData::getRightNextHop() const
+{
+	return RightNextHop;
+}
+
+QString VpnAccountData::getLeftNextHop() const
+{
+	return LeftNextHop;
+}
+
+bool VpnAccountData::getDisableOpportunisticEncryption() const
+{
+	return disableOpportunisticEncryption;
+}
+
+bool VpnAccountData::getUseMssfix() const
+{
+	return useMssfix;
+}
+
+bool VpnAccountData::getUseFragment() const
+{
+	return useFragment;
+}
+
+int VpnAccountData::getMssfix() const
+{
+	return Mssfix;
+}
+
+int VpnAccountData::getFragment() const
+{
+	return Fragment;
+}
+
+int VpnAccountData::getPeerTimeout() const
+{
+	return PeerTimeout;
+}
 
 /* set methods */
 void VpnAccountData::setConnectionType( ConnectionType type )
@@ -562,6 +765,7 @@ void VpnAccountData::setGateway( const QString &Gateway )
 {
 	this->Gateway = Gateway;
 }
+
 void VpnAccountData::setID( const QString &ID )
 {
 	this->ID = ID;
@@ -637,6 +841,11 @@ void VpnAccountData::setUseLocalPort( bool useLocalPort )
 	this->useLocalPort = useLocalPort;
 }
 
+void VpnAccountData::setUseRemotePort( bool useRemotePort )
+{
+	this->useRemotePort = useRemotePort;
+}
+
 void VpnAccountData::setUseAdvancedSettings( bool useAdvancedSettings )
 {
 	this->useAdvancedSettings = useAdvancedSettings;
@@ -652,9 +861,19 @@ void VpnAccountData::setLocalPort( int port )
 	this->LocalPort = port;
 }
 
-void VpnAccountData::setRemoteNet( const QString& RemoteNet )
+void VpnAccountData::setRemotePort( int port )
 {
-	this->RemoteNet = RemoteNet;
+	this->RemotePort = port;
+}
+
+void VpnAccountData::setRemoteNetAddr( const QString& RemoteNetAddr )
+{
+	this->RemoteNetAddr = RemoteNetAddr;
+}
+
+void VpnAccountData::setRemoteNetMask( const QString& RemoteNetMask )
+{
+	this->RemoteNetMask = RemoteNetMask;
 }
 
 void VpnAccountData::setPreSharedKey( const QString& PreSharedKey )
@@ -916,6 +1135,7 @@ void VpnAccountData::setUseUserdefinedPort(bool useUserdefinedPort)
 {
 	this->useUserdefinedPort = useUserdefinedPort;
 }
+
 void VpnAccountData::setUserdefinedPort(int UserdefinedPort)
 {
 	this->UserdefinedPort = UserdefinedPort;
@@ -966,12 +1186,132 @@ void VpnAccountData::setDisableLzoCompression(bool disableLzoCompression )
 	this->disableLzoCompression = disableLzoCompression;
 }
 
-void VpnAccountData::setAuthWithUsernameAndPassword(bool AuthWithUsernameAndPassword )
+void VpnAccountData::setAuthWithUsernameAndPassword(bool authWithUsernameAndPassword )
 {
-		this->AuthWithUsernameAndPassword = AuthWithUsernameAndPassword;
+		this->authWithUsernameAndPassword = authWithUsernameAndPassword;
 }
 
 void VpnAccountData::setAllowEmptyGroupPassword( bool allowEmptyGroupPassword )
 {
 	this->allowEmptyGroupPassword = allowEmptyGroupPassword;
 }
+
+void VpnAccountData::setUseUserdefiniedCipher( bool useUserdefiniedCipher )
+{
+	this->useUserdefiniedCipher = useUserdefiniedCipher;
+}
+
+void VpnAccountData::setUserdefiniedCipher( QString UserdefiniedCipher )
+{
+	this->UserdefiniedCipher = UserdefiniedCipher;
+}
+
+void VpnAccountData::setUseRedirectGateway( bool useRedirectGateway )
+{
+	this->useRedirectGateway = useRedirectGateway;
+}
+
+void VpnAccountData::setUseTlsAuth( bool useTlsAuth )
+{
+	this->useTlsAuth = useTlsAuth;
+}
+
+void VpnAccountData::setTlsAuthFile( QString TlsAuthFile )
+{
+	this->TlsAuthFile = TlsAuthFile;
+}
+
+void VpnAccountData::setHttpProxy( QString HttpProxy )
+{
+	this->HttpProxy = HttpProxy;
+}
+
+void VpnAccountData::setUseHttpProxy( bool useHttpProxy )
+{
+	this->useHttpProxy = useHttpProxy;
+}
+
+void VpnAccountData::setHttpProxyPort( int HttpProxyPort )
+{
+	this->HttpProxyPort = HttpProxyPort;
+}
+
+void VpnAccountData::setHttpProxyTimeout( int HttpProxyTimeout )
+{
+	this->HttpProxyTimeout = HttpProxyTimeout;
+}
+
+void VpnAccountData::setDontSaveUsername( bool dontSaveUsername)
+{
+	this->dontSaveUsername = dontSaveUsername;
+}
+
+void VpnAccountData::setUseModeConfig( bool useModeConfig)
+{
+	this->useModeConfig = useModeConfig;
+}
+
+void VpnAccountData::setExchangeMode( QString ExchangeMode )
+{
+	this->ExchangeMode  = ExchangeMode;
+}
+
+void VpnAccountData::setUseReconnectDelay( bool useReconnectDelay )
+{
+	this->useReconnectDelay = useReconnectDelay;
+}
+
+void VpnAccountData::setReconnectDelay( int ReconnectDelay )
+{
+	this->ReconnectDelay = ReconnectDelay;
+}
+
+void VpnAccountData::setUseTlsRemoteHost( bool useTlsRemoteHost )
+{
+	this->useTlsRemoteHost = useTlsRemoteHost;
+}
+
+void VpnAccountData::setTlsRemoteHost( QString TlsRemoteHost )
+{
+	this->TlsRemoteHost = TlsRemoteHost;
+}
+
+void VpnAccountData::setRightNextHop( QString RightNextHop )
+{
+	this->RightNextHop = RightNextHop;
+}
+
+void VpnAccountData::setLeftNextHop( QString LeftNextHop )
+{
+	this->LeftNextHop = LeftNextHop;
+}
+
+ void VpnAccountData::setDisableOpportunisticEncryption( bool disableOpportunisticEncryption )
+{
+	this->disableOpportunisticEncryption = disableOpportunisticEncryption;
+}
+
+ void VpnAccountData::setUseMssfix( bool useMssfix )
+{
+	this->useMssfix = useMssfix;
+}
+
+ void VpnAccountData::setUseFragment(  bool useFragment)
+{
+	this->useFragment = useFragment;
+}
+
+ void VpnAccountData::setMssfix(  int Mssfix)
+{
+	this->Mssfix = Mssfix;
+}
+
+ void VpnAccountData::setFragment(  int Fragment)
+{
+	this->Fragment = Fragment;
+}
+
+void VpnAccountData::setPeerTimeout( int PeerTimeout )
+{
+	this->PeerTimeout = PeerTimeout;
+}
